@@ -16,5 +16,5 @@ CREATE TABLE `iptables` (
   `target` varchar(10) DEFAULT NULL COMMENT 'ACCEPT DROP REJECT LOG',
   `active` enum('n','y') NOT NULL DEFAULT 'y',
   PRIMARY KEY (`iptables_id`)
-) ENGINE=MyISAM AUTO_INCREMENT=5 DEFAULT CHARSET=utf8;
+) AUTO_INCREMENT=5 DEFAULT CHARSET=utf8;
 
