@@ -12,7 +12,7 @@ CREATE TABLE `client_message_template` (
   `subject` varchar(255) DEFAULT NULL,
   `message` text,
   PRIMARY KEY (`client_message_template_id`)
-) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
+) DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
 ALTER TABLE  `spamfilter_policy` ADD  `policyd_quota_in` int(11) NOT NULL DEFAULT  '-1',
 ADD  `policyd_quota_in_period` int(11) NOT NULL DEFAULT  '24',
 ADD  `policyd_quota_out` int(11) NOT NULL DEFAULT  '-1',
