@@ -28,6 +28,10 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
+if(version_compare(phpversion(), '7.0', '<')) {
+	require_once 'compatibility.inc.php';
+}
+
 //* Enable gzip compression for the interface
 ob_start('ob_gzhandler');
 
@@ -35,21 +39,21 @@ ob_start('ob_gzhandler');
 if(isset($conf['timezone']) && $conf['timezone'] != '') date_default_timezone_set($conf['timezone']);
 
 //* Set error reporting level when we are not on a developer system
-if(DEVSYSTEM == 0) {
-	@ini_set('error_reporting', E_ALL & ~E_NOTICE & ~E_DEPRECATED);
+if(DEVSYSTEM !== true) {
+	@ini_set('error_reporting', E_ALL & ~E_NOTICE & ~E_DEPRECATED & ~E_WARNING);
 }
 
 /*
     Application Class
 */
-class app {
+class app extends stdClass {
 
 	private $_language_inc = 0;
 	private $_wb;
 	private $_loaded_classes = array();
 	private $_conf;
 	private $_security_config;
-	
+
 	public $loaded_plugins = array();
 
 	public function __construct() {
@@ -58,7 +62,7 @@ class app {
 		if (isset($_REQUEST['GLOBALS']) || isset($_FILES['GLOBALS']) || isset($_REQUEST['s']) || isset($_REQUEST['s_old']) || isset($_REQUEST['conf'])) {
 			die('Internal Error: var override attempt detected');
 		}
-		
+
 		$this->_conf = $conf;
 		if($this->_conf['start_db'] == true) {
 			$this->load('db_'.$this->_conf['db_type']);
@@ -70,21 +74,21 @@ class app {
 		}
 		$this->uses('functions'); // we need this before all others!
 		$this->uses('auth,plugin,ini_parser,getconf');
-		
+
 	}
 
 	public function __get($prop) {
 		if(property_exists($this, $prop)) return $this->{$prop};
-		
+
 		$this->uses($prop);
 		if(property_exists($this, $prop)) return $this->{$prop};
 		else trigger_error('Undefined property ' . $prop . ' of class app', E_USER_WARNING);
 	}
-	
+
 	public function __destruct() {
 		session_write_close();
 	}
-	
+
 	public function initialize_session() {
 		//* Start the session
 		if($this->_conf['start_session'] == true) {
@@ -118,7 +122,7 @@ class app {
 			} else {
 				session_set_cookie_params(0,'/',$cookie_domain,$cookie_secure,true); // until browser is closed
 			}
-			
+
 			session_set_save_handler( array($this->session, 'open'),
 				array($this->session, 'close'),
 				array($this->session, 'read'),
@@ -126,16 +130,19 @@ class app {
 				array($this->session, 'destroy'),
 				array($this->session, 'gc'));
 
+			ini_set('session.cookie_httponly', true);
+			@ini_set('session.cookie_samesite', 'Lax');
+
 			session_start();
-			
+
 			//* Initialize session variables
 			if(!isset($_SESSION['s']['id']) ) $_SESSION['s']['id'] = session_id();
-			if(empty($_SESSION['s']['theme'])) $_SESSION['s']['theme'] = $conf['theme'];
-			if(empty($_SESSION['s']['language'])) $_SESSION['s']['language'] = $conf['language'];
+			if(empty($_SESSION['s']['theme'])) $_SESSION['s']['theme'] = $this->_conf['theme'];
+			if(empty($_SESSION['s']['language'])) $_SESSION['s']['language'] = $this->_conf['language'];
 		}
 
 	}
-	
+
 	public function uses($classes) {
 		$cl = explode(',', $classes);
 		if(is_array($cl)) {
@@ -160,7 +167,7 @@ class app {
 			}
 		}
 	}
-	
+
 	public function conf($plugin, $key, $value = null) {
 		if(is_null($value)) {
 			$tmpconf = $this->db->queryOneRecord("SELECT `value` FROM `sys_config` WHERE `group` = ? AND `name` = ?", $plugin, $key);
@@ -205,6 +212,12 @@ class app {
 		}
 	}
 
+	public function auth_log($msg) {
+		$authlog_handle = fopen($this->_conf['ispconfig_log_dir'].'/auth.log', 'a');
+		fwrite($authlog_handle, $msg . PHP_EOL);
+		fclose($authlog_handle);
+	}
+
 	/** Priority values are: 0 = DEBUG, 1 = WARNING,  2 = ERROR */
 	public function error($msg, $next_link = '', $stop = true, $priority = 1) {
 		//$this->uses("error");
@@ -284,6 +297,7 @@ class app {
 			$this->tpl->setVar('datalog_changes_end_txt', $this->lng('datalog_changes_end_txt'));
 			$this->tpl->setVar('datalog_changes_count', $datalog['count']);
 			$this->tpl->setLoop('datalog_changes', $datalog['entries']);
+			$this->tpl->setVar('datalog_changes_close_txt', $this->lng('datalog_changes_close_txt'));
 		} else {
 			$this->tpl->setVar('app_version', '');
 		}
@@ -333,7 +347,23 @@ class app {
 		$this->tpl->setVar('globalsearch_noresults_limit_txt', $this->lng('globalsearch_noresults_limit_txt'));
 		$this->tpl->setVar('globalsearch_searchfield_watermark_txt', $this->lng('globalsearch_searchfield_watermark_txt'));
 	}
-	
+
+	public function is_under_maintenance() {
+		$system_config_misc = $this->getconf->get_global_config('misc');
+		$maintenance_mode = 'n';
+		$maintenance_mode_exclude_ips = [];
+
+		if (!empty($system_config_misc['maintenance_mode'])) {
+			$maintenance_mode = $system_config_misc['maintenance_mode'];
+		}
+
+		if (!empty($system_config_misc['maintenance_mode_exclude_ips'])) {
+			$maintenance_mode_exclude_ips = array_map('trim', explode(',', $system_config_misc['maintenance_mode_exclude_ips']));
+		}
+
+		return 'y' === $maintenance_mode && !in_array($_SERVER['REMOTE_ADDR'], $maintenance_mode_exclude_ips);
+	}
+
 	private function get_cookie_domain() {
 		$sec_config = $this->getconf->get_security_config('permissions');
 		$proxy_panel_allowed = $sec_config['reverse_proxy_panel_allowed'];
@@ -356,15 +386,15 @@ class app {
 			$forwarded_host = (isset($_SERVER['HTTP_X_FORWARDED_HOST']) ? $_SERVER['HTTP_X_FORWARDED_HOST'] : null );
 			if($forwarded_host !== null && $forwarded_host !== $cookie_domain) {
 				// Just check for complete domain name and not auto subdomains
-				$sql = "SELECT domain_id from web_domain where domain = '$forwarded_host'";
-				$recs = $this->db->queryOneRecord($sql);
+				$sql = "SELECT domain_id from web_domain where domain = ?";
+				$recs = $this->db->queryOneRecord($sql, $forwarded_host);
 				if($recs !== null) {
 					$cookie_domain = $forwarded_host;
 				}
 				unset($forwarded_host);
 			}
 		}
-		
+
 		return $cookie_domain;
 	}
 
@@ -373,7 +403,7 @@ class app {
 //** Initialize application (app) object
 //* possible future =  new app($conf);
 $app = new app();
-/* 
+/*
    split session creation out of constructor is IMHO better.
    otherwise we have some circular references to global $app like in
    getconfig property of App - RA
@@ -382,7 +412,7 @@ $app->initialize_session();
 
 // load and enable PHP Intrusion Detection System (PHPIDS)
 $ids_security_config = $app->getconf->get_security_config('ids');
-		
+
 if(is_dir(ISPC_CLASS_PATH.'/IDS') && !defined('REMOTE_API_CALL') && ($ids_security_config['ids_anon_enabled'] == 'yes' || $ids_security_config['ids_user_enabled'] == 'yes' || $ids_security_config['ids_admin_enabled'] == 'yes')) {
 	$app->uses('ids');
 	$app->ids->start();
