@@ -42,145 +42,43 @@ class remoting_dns extends remoting {
 	// DNS Function --------------------------------------------------------------------------------------------------
 
 	//* Create Zone with Template
-	public function dns_templatezone_add($session_id, $client_id, $template_id, $domain, $ip, $ns1, $ns2, $email) {
+	public function dns_templatezone_add($session_id, $client_id, $template_id, $domain, $ip, $ns1, $ns2, $email, $ipv6 = '') {
 		global $app, $conf;
+
 		if(!$this->checkPerm($session_id, 'dns_templatezone_add')) {
 			throw new SoapFault('permission_denied', 'You do not have the permissions to access this function.');
+		}
+
+		$client_id = $app->functions->intval($client_id);
+
+		// Get client group id
+		$rec = $app->db->queryOneRecord("SELECT groupid FROM sys_group WHERE client_id = ?", $client_id);
+		if(isset($rec['groupid'])) {
+			$client_group_id = $app->functions->intval($rec['groupid']);
+		} else {
+			throw new SoapFault('no_group_found', 'There is no group for this client ID.');
 			return false;
 		}
 
-		$client = $app->db->queryOneRecord("SELECT default_dnsserver FROM client WHERE client_id = ?", $client_id);
-		$server_id = $client["default_dnsserver"];
-		$template_record = $app->db->queryOneRecord("SELECT * FROM dns_template WHERE template_id = ?", $template_id);
-		$fields = explode(',', $template_record['fields']);
-		$tform_def_file = "../../web/dns/form/dns_soa.tform.php";
-		$app->uses('tform');
-		$app->tform->loadFormDef($tform_def_file);
-		$app->uses('tpl,validate_dns,remoting_lib');
-		
+		$app->uses('remoting_lib,dns_wizard');
 		$app->remoting_lib->loadUserProfile($client_id);
 
-		//* replace template placeholders
-		$tpl_content = $template_record['template'];
-		if($domain != '') $tpl_content = str_replace('{DOMAIN}', $domain, $tpl_content);
-		if($ip != '') $tpl_content = str_replace('{IP}', $ip, $tpl_content);
-		if($ns1 != '') $tpl_content = str_replace('{NS1}', $ns1, $tpl_content);
-		if($ns2 != '') $tpl_content = str_replace('{NS2}', $ns2, $tpl_content);
-		if($email != '') $tpl_content = str_replace('{EMAIL}', $email, $tpl_content);
+		$create = $app->dns_wizard->create([
+			'client_group_id' => $client_group_id,
+			'template_id' => $template_id,
+			'domain' => $domain,
+			'ip' => $ip,
+			'ns1' => $ns1,
+			'ns2' => $ns2,
+			'email' => $email,
+			'ipv6' => $ipv6,
+		]);
 
-		//* Parse the template
-		$tpl_rows = explode("\n", $tpl_content);
-		$section = '';
-		$vars = array();
-		$dns_rr = array();
-		foreach($tpl_rows as $row) {
-			$row = trim($row);
-			if(substr($row, 0, 1) == '[') {
-				if($row == '[ZONE]') {
-					$section = 'zone';
-				} elseif($row == '[DNS_RECORDS]') {
-					$section = 'dns_records';
-				} else {
-					die('Unknown section type');
-				}
-			} else {
-				if($row != '') {
-					//* Handle zone section
-					if($section == 'zone') {
-						$parts = explode('=', $row);
-						$key = trim($parts[0]);
-						$val = trim($parts[1]);
-						if($key != '') $vars[$key] = $val;
-					}
-					//* Handle DNS Record rows
-					if($section == 'dns_records') {
-						$parts = explode('|', $row);
-						$dns_rr[] = array(
-							'name' => $parts[1],
-							'type' => $parts[0],
-							'data' => $parts[2],
-							'aux'  => $parts[3],
-							'ttl'  => $parts[4]
-						);
-					}
-				}
-			}
-		} // end foreach
-
-		if($vars['origin'] == '') $error .= $app->lng('error_origin_empty').'<br />';
-		if($vars['ns'] == '') $error .= $app->lng('error_ns_empty').'<br />';
-		if($vars['mbox'] == '') $error .= $app->lng('error_mbox_empty').'<br />';
-		if($vars['refresh'] == '') $error .= $app->lng('error_refresh_empty').'<br />';
-		if($vars['retry'] == '') $error .= $app->lng('error_retry_empty').'<br />';
-		if($vars['expire'] == '') $error .= $app->lng('error_expire_empty').'<br />';
-		if($vars['minimum'] == '') $error .= $app->lng('error_minimum_empty').'<br />';
-		if($vars['ttl'] == '') $error .= $app->lng('error_ttl_empty').'<br />';
-		if(!isset($vars['xfer'])) $vars['xfer'] = '';
-
-		if($error == '') {
-			// Insert the soa record
-			$tmp = $app->db->queryOneRecord("SELECT userid,default_group FROM sys_user WHERE client_id = ?", $client_id);
-			$sys_userid = $tmp['userid'];
-			$sys_groupid = $tmp['default_group'];
-			unset($tmp);
-			$origin = $vars['origin'];
-			$ns = $vars['ns'];
-			$mbox = str_replace('@', '.', $vars['mbox']);
-			$refresh = $vars['refresh'];
-			$retry = $vars['retry'];
-			$expire = $vars['expire'];
-			$minimum = $vars['minimum'];
-			$ttl = $vars['ttl'];
-			$xfer = $vars['xfer'];
-			$also_notify = $vars['also_notify'];
-			$update_acl = $vars['update_acl'];
-			$serial = $app->validate_dns->increase_serial(0);
-			$insert_data = array(
-				"sys_userid" => $sys_userid,
-				"sys_groupid" => $sys_groupid,
-				"sys_perm_user" => 'riud',
-				"sys_perm_group" => 'riud',
-				"sys_perm_other" => '',
-				"server_id" => $server_id,
-				"origin" => $origin,
-				"ns" => $ns,
-				"mbox" => $mbox,
-				"serial" => $serial,
-				"refresh" => $refresh,
-				"retry" => $retry,
-				"expire" => $expire,
-				"minimum" => $minimum,
-				"ttl" => $ttl,
-				"active" => 'Y',
-				"xfer" => $xfer,
-				"also_notify" => $also_notify,
-				"update_acl" => $update_acl
-			);
-			$dns_soa_id = $app->db->datalogInsert('dns_soa', $insert_data, 'id');
-			// Insert the dns_rr records
-			if(is_array($dns_rr) && $dns_soa_id > 0) {
-				foreach($dns_rr as $rr) {
-					$insert_data = array(
-						"sys_userid" => $sys_userid,
-						"sys_groupid" => $sys_groupid,
-						"sys_perm_user" => 'riud',
-						"sys_perm_group" => 'riud',
-						"sys_perm_other" => '',
-						"server_id" => $server_id,
-						"zone" => $dns_soa_id,
-						"name" => $rr['name'],
-						"type" => $rr['type'],
-						"data" => $rr['data'],
-						"aux" => $rr['aux'],
-						"ttl" => $rr['ttl'],
-						"active" => 'Y'
-					);
-					$dns_rr_id = $app->db->datalogInsert('dns_rr', $insert_data, 'id');
-				}
-			}
-			exit;
+		if ($create == 'ok') {
+			return true;
 		} else {
-			throw new SoapFault('permission_denied', $error);
+			throw new SoapFault('dns_wizard_error', $create);
+			return false;
 		}
 	}
 
@@ -197,7 +95,7 @@ class remoting_dns extends remoting {
 		$app->remoting_lib->loadFormDef('../dns/form/dns_soa.tform.php');
 		return $app->remoting_lib->getDataRecord($primary_id);
 	}
-	
+
 	//* Get slave zone details
 	public function dns_slave_get($session_id, $primary_id) {
 		global $app;
@@ -211,16 +109,16 @@ class remoting_dns extends remoting {
 		return $app->remoting_lib->getDataRecord($primary_id);
 	}
 
-	
+
 	//* Add a slave zone
-    public function dns_slave_add($session_id, $client_id, $params) {
+	public function dns_slave_add($session_id, $client_id, $params) {
 		if(!$this->checkPerm($session_id, 'dns_zone_add')) {
 			throw new SoapFault('permission_denied', 'You do not have the permissions to access this function.');
 			return false;
 		}
 		return $this->insertQuery('../dns/form/dns_slave.tform.php', $client_id, $params);
-    }
-	
+	}
+
 	//* Update a slave zone
 	public function dns_slave_update($session_id, $client_id, $primary_id, $params) {
 		if(!$this->checkPerm($session_id, 'dns_zone_update')) {
@@ -231,14 +129,14 @@ class remoting_dns extends remoting {
 		return $affected_rows;
 	}
 
-    //* Delete a slave zone
-    public function dns_slave_delete($session_id, $primary_id) {
+	//* Delete a slave zone
+	public function dns_slave_delete($session_id, $primary_id) {
 		if(!$this->checkPerm($session_id, 'dns_zone_delete')) {
 			throw new SoapFault('permission_denied', 'You do not have the permissions to access this function.');
 			return false;
 		}
 		return $this->deleteQuery('../dns/form/dns_slave.tform.php', $primary_id);
-    }
+	}
 
 	//* Get record id by origin
 	public function dns_zone_get_id($session_id, $origin) {
@@ -249,7 +147,7 @@ class remoting_dns extends remoting {
 			return false;
 		}
 
-		if(!preg_match('/^[a-z0-9][a-z0-9\-]+[a-z0-9](\.[a-z]{2,4})+$/i', $origin)){
+		if(!preg_match('/^[\w\.\-]{1,64}\.[a-zA-Z0-9\-]{2,63}$/', $origin)){
 			throw new SoapFault('no_domain_found', 'Invalid domain name.');
 			return false;
 		}
@@ -296,12 +194,12 @@ class remoting_dns extends remoting {
 
 	private function dns_rr_get($session_id, $primary_id, $rr_type = 'A') {
 		global $app;
-	
+
 		$rr_type = strtolower($rr_type);
 		if(!preg_match('/^[a-z]+$/', $rr_type)) {
 			throw new SoapFault('permission denied', 'Invalid rr type');
 		}
-		
+
 		if(!$this->checkPerm($session_id, 'dns_' . $rr_type . '_get')) {
 			throw new SoapFault('permission_denied', 'You do not have the permissions to access this function.');
 		}
@@ -309,14 +207,14 @@ class remoting_dns extends remoting {
 		$app->remoting_lib->loadFormDef('../dns/form/dns_' . $rr_type . '.tform.php');
 		return $app->remoting_lib->getDataRecord($primary_id);
 	}
-	
+
 	//* Add a record
 	private function dns_rr_add($session_id, $client_id, $params, $update_serial=false, $rr_type = 'A') {
 		$rr_type = strtolower($rr_type);
 		if(!preg_match('/^[a-z]+$/', $rr_type)) {
 			throw new SoapFault('permission denied', 'Invalid rr type');
 		}
-		
+
 		if(!$this->checkPerm($session_id, 'dns_' . $rr_type . '_add')) {
 			throw new SoapFault('permission_denied', 'You do not have the permissions to access this function.');
 		}
@@ -332,7 +230,7 @@ class remoting_dns extends remoting {
 		if(!preg_match('/^[a-z]+$/', $rr_type)) {
 			throw new SoapFault('permission denied', 'Invalid rr type');
 		}
-		
+
 		if(!$this->checkPerm($session_id, 'dns_' . $rr_type . '_update')) {
 			throw new SoapFault('permission_denied', 'You do not have the permissions to access this function.');
 			return false;
@@ -343,7 +241,7 @@ class remoting_dns extends remoting {
 		}
 		return $affected_rows;
 	}
-	
+
 	//* Delete a record
 	private function dns_rr_delete($session_id, $primary_id, $update_serial=false, $rr_type = 'A') {
 		$rr_type = strtolower($rr_type);
@@ -359,9 +257,9 @@ class remoting_dns extends remoting {
 		$affected_rows = $this->deleteQuery('../dns/form/dns_' . $rr_type . '.tform.php', $primary_id);
 		return $affected_rows;
 	}
-	
+
 	// ----------------------------------------------------------------------------------------------------------------
-	
+
 	//* Get record details
 	public function dns_aaaa_get($session_id, $primary_id) {
 		return $this->dns_rr_get($session_id, $primary_id, 'AAAA');
@@ -428,6 +326,28 @@ class remoting_dns extends remoting {
 
 	// ----------------------------------------------------------------------------------------------------------------
 
+	//* Get record details
+	public function dns_caa_get($session_id, $primary_id) {
+		return $this->dns_rr_get($session_id, $primary_id, 'CAA');
+	}
+
+	//* Add a record
+	public function dns_caa_add($session_id, $client_id, $params, $update_serial=false) {
+		return $this->dns_rr_add($session_id, $client_id, $params, $update_serial, 'CAA');
+	}
+
+	//* Update a record
+	public function dns_caa_update($session_id, $client_id, $primary_id, $params, $update_serial=false) {
+		return $this->dns_rr_update($session_id, $client_id, $primary_id, $params, $update_serial, 'CAA');
+	}
+
+	//* Delete a record
+	public function dns_caa_delete($session_id, $primary_id, $update_serial=false) {
+		return $this->dns_rr_delete($session_id, $primary_id, $update_serial, 'CAA');
+	}
+
+	// ----------------------------------------------------------------------------------------------------------------
+
 	//* Get record details
 	public function dns_cname_get($session_id, $primary_id) {
 		return $this->dns_rr_get($session_id, $primary_id, 'CNAME');
@@ -450,6 +370,28 @@ class remoting_dns extends remoting {
 
 	// ----------------------------------------------------------------------------------------------------------------
 
+	//* Get record details
+	public function dns_dname_get($session_id, $primary_id) {
+		return $this->dns_rr_get($session_id, $primary_id, 'DNAME');
+	}
+
+	//* Add a record
+	public function dns_dname_add($session_id, $client_id, $params, $update_serial=false) {
+		return $this->dns_rr_add($session_id, $client_id, $params, $update_serial, 'DNAME');
+	}
+
+	//* Update a record
+	public function dns_dname_update($session_id, $client_id, $primary_id, $params, $update_serial=false) {
+		return $this->dns_rr_update($session_id, $client_id, $primary_id, $params, $update_serial, 'DNAME');
+	}
+
+	//* Delete a record
+	public function dns_dname_delete($session_id, $primary_id, $update_serial=false) {
+		return $this->dns_rr_delete($session_id, $primary_id, $update_serial, 'DNAME');
+	}
+
+	// ----------------------------------------------------------------------------------------------------------------
+
 	//* Get record details
 	public function dns_hinfo_get($session_id, $primary_id) {
 		return $this->dns_rr_get($session_id, $primary_id, 'HINFO');
@@ -470,6 +412,29 @@ class remoting_dns extends remoting {
 		return $this->dns_rr_delete($session_id, $primary_id, $update_serial, 'HINFO');
 	}
 
+
+	// ----------------------------------------------------------------------------------------------------------------
+
+	//* Get record details
+	public function dns_loc_get($session_id, $primary_id) {
+		return $this->dns_rr_get($session_id, $primary_id, 'LOC');
+	}
+
+	//* Add a record
+	public function dns_loc_add($session_id, $client_id, $params, $update_serial=false) {
+		return $this->dns_rr_add($session_id, $client_id, $params, $update_serial, 'LOC');
+	}
+
+	//* Update a record
+	public function dns_loc_update($session_id, $client_id, $primary_id, $params, $update_serial=false) {
+		return $this->dns_rr_update($session_id, $client_id, $primary_id, $params, $update_serial, 'LOC');
+	}
+
+	//* Delete a record
+	public function dns_loc_delete($session_id, $primary_id, $update_serial=false) {
+		return $this->dns_rr_delete($session_id, $primary_id, $update_serial, 'LOC');
+	}
+
 	// ----------------------------------------------------------------------------------------------------------------
 
 	//* Get record details
@@ -494,6 +459,28 @@ class remoting_dns extends remoting {
 
 	// ----------------------------------------------------------------------------------------------------------------
 
+	//* Get record details
+	public function dns_naptr_get($session_id, $primary_id) {
+		return $this->dns_rr_get($session_id, $primary_id, 'NAPTR');
+	}
+
+	//* Add a record
+	public function dns_naptr_add($session_id, $client_id, $params, $update_serial=false) {
+		return $this->dns_rr_add($session_id, $client_id, $params, $update_serial, 'NAPTR');
+	}
+
+	//* Update a record
+	public function dns_naptr_update($session_id, $client_id, $primary_id, $params, $update_serial=false) {
+		return $this->dns_rr_update($session_id, $client_id, $primary_id, $params, $update_serial, 'NAPTR');
+	}
+
+	//* Delete a record
+	public function dns_naptr_delete($session_id, $primary_id, $update_serial=false) {
+		return $this->dns_rr_delete($session_id, $primary_id, $update_serial, 'NAPTR');
+	}
+
+	// ----------------------------------------------------------------------------------------------------------------
+
 	//* Get record details
 	public function dns_ns_get($session_id, $primary_id) {
 		return $this->dns_rr_get($session_id, $primary_id, 'NS');
@@ -516,6 +503,28 @@ class remoting_dns extends remoting {
 
 	// ----------------------------------------------------------------------------------------------------------------
 
+	//* Get record details
+	public function dns_ds_get($session_id, $primary_id) {
+		return $this->dns_rr_get($session_id, $primary_id, 'DS');
+	}
+
+	//* Add a record
+	public function dns_ds_add($session_id, $client_id, $params, $update_serial=false) {
+		return $this->dns_rr_add($session_id, $client_id, $params, $update_serial, 'DS');
+	}
+
+	//* Update a record
+	public function dns_ds_update($session_id, $client_id, $primary_id, $params, $update_serial=false) {
+		return $this->dns_rr_update($session_id, $client_id, $primary_id, $params, $update_serial, 'DS');
+	}
+
+	//* Delete a record
+	public function dns_ds_delete($session_id, $primary_id, $update_serial=false) {
+		return $this->dns_rr_delete($session_id, $primary_id, $update_serial, 'DS');
+	}
+
+	// ----------------------------------------------------------------------------------------------------------------
+
 	//* Get record details
 	public function dns_ptr_get($session_id, $primary_id) {
 		return $this->dns_rr_get($session_id, $primary_id, 'PTR');
@@ -582,6 +591,50 @@ class remoting_dns extends remoting {
 
 	// ----------------------------------------------------------------------------------------------------------------
 
+	//* Get record details
+	public function dns_sshfp_get($session_id, $primary_id) {
+		return $this->dns_rr_get($session_id, $primary_id, 'SSHFP');
+	}
+
+	//* Add a record
+	public function dns_sshfp_add($session_id, $client_id, $params, $update_serial=false) {
+		return $this->dns_rr_add($session_id, $client_id, $params, $update_serial, 'SSHFP');
+	}
+
+	//* Update a record
+	public function dns_sshfp_update($session_id, $client_id, $primary_id, $params, $update_serial=false) {
+		return $this->dns_rr_update($session_id, $client_id, $primary_id, $params, $update_serial, 'SSHFP');
+	}
+
+	//* Delete a record
+	public function dns_sshfp_delete($session_id, $primary_id, $update_serial=false) {
+		return $this->dns_rr_delete($session_id, $primary_id, $update_serial, 'SSHFP');
+	}
+
+	// ----------------------------------------------------------------------------------------------------------------
+
+	//* Get record details
+	public function dns_tlsa_get($session_id, $primary_id) {
+		return $this->dns_rr_get($session_id, $primary_id, 'TLSA');
+	}
+
+	//* Add a record
+	public function dns_tlsa_add($session_id, $client_id, $params, $update_serial=false) {
+		return $this->dns_rr_add($session_id, $client_id, $params, $update_serial, 'TLSA');
+	}
+
+	//* Update a record
+	public function dns_tlsa_update($session_id, $client_id, $primary_id, $params, $update_serial=false) {
+		return $this->dns_rr_update($session_id, $client_id, $primary_id, $params, $update_serial, 'TLSA');
+	}
+
+	//* Delete a record
+	public function dns_tlsa_delete($session_id, $primary_id, $update_serial=false) {
+		return $this->dns_rr_delete($session_id, $primary_id, $update_serial, 'TLSA');
+	}
+
+	// ----------------------------------------------------------------------------------------------------------------
+
 	//* Get record details
 	public function dns_txt_get($session_id, $primary_id) {
 		return $this->dns_rr_get($session_id, $primary_id, 'TXT');
@@ -626,6 +679,24 @@ class remoting_dns extends remoting {
 
 
 
+  //* Get All DNS Zones Templates by etruel and thom
+	public function dns_templatezone_get_all($session_id) {
+		global $app, $conf;
+	  if(!$this->checkPerm($session_id, 'dns_templatezone_add')) {
+			$this->server->fault('permission_denied', 'You do not have the permissions to access this function.');
+			return false;
+	  }
+		$sql ="SELECT * FROM dns_template";
+		$result = $app->db->queryAllRecords($sql);
+		if(isset($result)) {
+			return $result;
+		}
+		else {
+			throw new SoapFault('template_id_error', 'There is no DNS templates.');
+			return false;
+		}
+	}
+
 	/**
 	 *  Get all dns records for a zone
 	 * @param  int  session id
@@ -671,6 +742,39 @@ class remoting_dns extends remoting {
 			return false;
 		}
 	}
+	
+	/*
+	* Set DNSSec Algo and activate it if needed.
+	*
+	* @param int      session id
+	* @param int      client id
+	* @param string   algorithm 'NSEC3RSASHA1', 'ECDSAP256SHA256' or 'NSEC3RSASHA1,ECDSAP256SHA256' string
+	* @param boolean  update serial
+	*
+	* @author Tom Albers <kovoks@kovoks.nl> KovoKs B.V. 2023
+	*/
+	
+	public function dns_zone_set_dnssec($session_id, $client_id, $primary_id, $algo, $update_serial=false) {
+		global $app;
+		if(!$this->checkPerm($session_id, 'dns_zone_set_status')) {
+			throw new SoapFault('permission_denied', 'You do not have the permissions to access this function.');
+			return false;
+		}
+		
+		if(!in_array($algo, ['NSEC3RSASHA1', 'ECDSAP256SHA256', 'NSEC3RSASHA1,ECDSAP256SHA256'])) {
+			throw new SoapFault('permission_denied', 'You are not using a valid algorithm for this function.');
+			return false;
+		}
+		$params["dnssec_wanted"] = "Y";
+		$params["dnssec_algo"] = $algo;
+		$affected_rows = $this->updateQuery('../dns/form/dns_soa.tform.php', $client_id, $primary_id, $params);
+		if($update_serial) {
+			$this->increase_serial($session_id, $client_id, ["zone" => $primary_id]);
+
+		}
+		return $affected_rows;
+	}
+
 
 	private function increase_serial($session_id, $client_id, $params) {
 		global $app;
