@@ -59,11 +59,6 @@ class remoting {
 		$app->uses('remoting_lib');
 
 		$this->_methods = $methods;
-
-		/*
-        $this->app = $app;
-        $this->conf = $conf;
-		*/
 	}
 
 	//* remote login function
@@ -72,9 +67,7 @@ class remoting {
 		global $app, $conf;
 
 		// Maintenance mode
-		$app->uses('ini_parser,getconf');
-		$server_config_array = $app->getconf->get_global_config('misc');
-		if($server_config_array['maintenance_mode'] == 'y'){
+		if($app->is_under_maintenance()){
 			throw new SoapFault('maintenance_mode', 'This ISPConfig installation is currently under maintenance. We should be back shortly. Thank you for your patience.');
 			return false;
 		}
@@ -92,10 +85,20 @@ class remoting {
 		//* Delete old remoting sessions
 		$sql = "DELETE FROM remote_session WHERE tstamp < UNIX_TIMESTAMP()";
 		$app->db->query($sql);
+		
+		//* Check for max. login attempts
+		$ip_md5 = md5($_SERVER['REMOTE_ADDR']);
+		$sql = "SELECT * FROM `attempts_login` WHERE `ip`= ? AND  `login_time` > (NOW() - INTERVAL 5 MINUTE) LIMIT 1";
+		$alreadyfailed = $app->db->queryOneRecord($sql, $ip_md5);
+
+		if($alreadyfailed['times'] >= 10) {
+			throw new SoapFault('login_failure_limit', 'The login failure limit has been reached.');
+			return false;
+		}
 
 		if($client_login == true) {
 			$sql = "SELECT * FROM sys_user WHERE USERNAME = ?";
-			$user = $app->db->queryOneRecord($sql, $username);
+			$user = $app->db->queryOneRecord($sql, (string)$username);
 			if($user) {
 				$saved_password = stripslashes($user['passwort']);
 
@@ -111,6 +114,16 @@ class remoting {
 					}
 				}
 			} else {
+				if(!$alreadyfailed['times'] )
+				{
+					//* user login the first time wrong
+					$sql = "INSERT INTO `attempts_login` (`ip`, `times`, `login_time`) VALUES (?, 1, NOW())";
+					$app->db->query($sql, $ip_md5);
+				} elseif($alreadyfailed['times'] >= 1) {
+					//* update times wrong
+					$sql = "UPDATE `attempts_login` SET `times`=`times`+1, `login_time`=NOW() WHERE `ip` = ? ORDER BY `login_time` DESC LIMIT 1";
+					$app->db->query($sql, $ip_md5);
+				}
 				throw new SoapFault('client_login_failed', 'The login failed. Username or password wrong.');
 			}
 			if($user['active'] != 1) {
@@ -125,23 +138,42 @@ class remoting {
 			}
 
 			//* Create a remote user session
-			//srand ((double)microtime()*1000000);
-			$remote_session = md5(mt_rand().uniqid('ispco'));
+			// session id must begin with a char, not digit, to avoid mysql type confusion abuse
+			$remote_session = substr(str_shuffle('abcdefghijklmnopqrstuvwxyz'),0,1).bin2hex(random_bytes(20));
 			$remote_userid = $user['userid'];
 			$remote_functions = '';
 			$tstamp = time() + $this->session_timeout;
-			$sql = 'INSERT INTO remote_session (remote_session,remote_userid,remote_functions,client_login,tstamp'
-				.') VALUES (?, ?, ?, 1, $tstamp)';
-			$app->db->query($sql, $remote_session,$remote_userid,$remote_functions,$tstamp);
+			$ip = $_SERVER['REMOTE_ADDR'];
+			$sql = 'INSERT INTO remote_session (remote_session,remote_userid,remote_functions,client_login,tstamp,remote_ip'
+				.') VALUES (?, ?, ?, 1, ?, ?)';
+			$app->db->query($sql, $remote_session,$remote_userid,$remote_functions,$tstamp,$ip);
+			
+			//* Delete login attempts after successful login
+			$sql = "DELETE FROM `attempts_login` WHERE `ip`=?";
+			$app->db->query($sql, $ip_md5);
+			
 			return $remote_session;
 		} else {
-			$sql = "SELECT * FROM remote_user WHERE remote_username = ? and remote_password = md5(?)";
-			$remote_user = $app->db->queryOneRecord($sql, $username, $password);
-			if($remote_user['remote_userid'] > 0) {
+			$sql = "SELECT * FROM remote_user WHERE remote_username = ?";
+			$remote_user = $app->db->queryOneRecord($sql, (string)$username);
+			if($remote_user) {
+				if(substr($remote_user['remote_password'], 0, 1) === '$') {
+					if(crypt(stripslashes($password), $remote_user['remote_password']) != $remote_user['remote_password']) {
+						$remote_user = null;
+					}
+				} elseif(md5($password) == $remote_user['remote_password']) {
+					// update hash algo
+					$sql = 'UPDATE `remote_user` SET `remote_password` = ? WHERE `remote_username` = ?';
+					$app->db->query($sql, $app->auth->crypt_password($password), (string)$username);
+				} else {
+					$remote_user = null;
+				}
+			}
+			if($remote_user && $remote_user['remote_userid'] > 0) {
 				if (trim($remote_user['remote_ips']) != '') {
 					$allowed_ips = explode(',',$remote_user['remote_ips']);
-					foreach($allowed_ips as $i => $allowed) { 
-						if(!filter_var($allowed, FILTER_VALIDATE_IP)) { 
+					foreach($allowed_ips as $i => $allowed) {
+						if(!filter_var($allowed, FILTER_VALIDATE_IP)) {
 							// get the ip for a hostname
 							unset($allowed_ips[$i]);
 							$temp=dns_get_record($allowed, DNS_A+DNS_AAAA);
@@ -164,9 +196,9 @@ class remoting {
 					if(trim($remote_user['remote_ips']) == '') {
 						$remote_allowed=true;
 					} else {
-						$ip = inet_pton($_SERVER['REMOTE_ADDR']);
+						$ip_bin = inet_pton($ip);
 						foreach($allowed_ips as $allowed) {
-							if($ip == inet_pton(trim($allowed))) {
+							if($ip_bin == inet_pton(trim($allowed))) {
 								$remote_allowed=true;
 								break;
 							}
@@ -176,18 +208,35 @@ class remoting {
 				if(!$remote_allowed) {
 					throw new SoapFault('login_failed', 'The login is not allowed from '.$_SERVER['REMOTE_ADDR']);
 					return false;
-				}	
+				}
 				//* Create a remote user session
-				//srand ((double)microtime()*1000000);
-				$remote_session = md5(mt_rand().uniqid('ispco'));
+				// session id must begin with a char, not digit, to avoid mysql type confusion abuse
+				$remote_session = substr(str_shuffle('abcdefghijklmnopqrstuvwxyz'),0,1).bin2hex(random_bytes(20));
 				$remote_userid = $remote_user['remote_userid'];
 				$remote_functions = $remote_user['remote_functions'];
 				$tstamp = time() + $this->session_timeout;
-				$sql = 'INSERT INTO remote_session (remote_session,remote_userid,remote_functions,tstamp'
-					.') VALUES (?, ?, ?, ?)';
-				$app->db->query($sql, $remote_session,$remote_userid,$remote_functions,$tstamp);
+				$sql = 'INSERT INTO remote_session (remote_session,remote_userid,remote_functions,tstamp,remote_ip'
+					.') VALUES (?, ?, ?, ?, ?)';
+				$app->db->query($sql, $remote_session,$remote_userid,$remote_functions,$tstamp, $ip);
+				
+				//* Delete login attempts after successful login
+				$sql = "DELETE FROM `attempts_login` WHERE `ip`=?";
+				$app->db->query($sql, $ip_md5);
+				
 				return $remote_session;
 			} else {
+				
+				if(!$alreadyfailed['times'] )
+				{
+					//* user login the first time wrong
+					$sql = "INSERT INTO `attempts_login` (`ip`, `times`, `login_time`) VALUES (?, 1, NOW())";
+					$app->db->query($sql, $ip_md5);
+				} elseif($alreadyfailed['times'] >= 1) {
+					//* update times wrong
+					$sql = "UPDATE `attempts_login` SET `times`=`times`+1, `login_time`=NOW() WHERE `ip` = ? ORDER BY `login_time` DESC LIMIT 1";
+					$app->db->query($sql, $ip_md5);
+				}
+				
 				throw new SoapFault('login_failed', 'The login failed. Username or password wrong.');
 				return false;
 			}
@@ -206,7 +255,7 @@ class remoting {
 		}
 
 		$sql = "DELETE FROM remote_session WHERE remote_session = ?";
-		if($app->db->query($sql, $session_id) != false) {
+		if($app->db->query($sql, (string)$session_id) != false) {
 			return true;
 		} else {
 			return false;
@@ -375,22 +424,22 @@ class remoting {
 
 		//* Load the form definition
 		$app->remoting_lib->loadFormDef($formdef_file);
-		
+
 		//* get old record and merge with params, so only new values have to be set in $params
                $old_rec = $app->remoting_lib->getDataRecord($primary_id, $client_id);
-		
+
 		foreach ($app->remoting_lib->formDef['fields'] as $fieldName => $fieldConf)
         {
             if ($fieldConf['formtype'] === 'PASSWORD' && empty($params[$fieldName])) {
                 unset($old_rec[$fieldName]);
             }
         }
-		
+
 		$params = $app->functions->array_merge($old_rec,$params);
 
 		//* Get the SQL query
 		$sql = $app->remoting_lib->getSQL($params, 'UPDATE', $primary_id);
-		
+
 		// throw new SoapFault('debug', $sql);
 		if($app->remoting_lib->errorMessage != '') {
 			throw new SoapFault('data_processing_error', $app->remoting_lib->errorMessage);
@@ -516,12 +565,61 @@ class remoting {
 			throw new SoapFault('session_id_empty', 'The SessionID is empty.');
 			return false;
 		}
+		
+		if(!is_string($session_id)) {
+			throw new SoapFault('session_id_nostring', 'Wrong SessionID datatype.');
+			return false;
+		}
+		
+		$ip_md5 = md5($_SERVER['REMOTE_ADDR']);
+		$sql = "SELECT * FROM `attempts_login` WHERE `ip`= ? AND  `login_time` > (NOW() - INTERVAL 5 MINUTE) LIMIT 1";
+		$alreadyfailed = $app->db->queryOneRecord($sql, $ip_md5);
+
+		if($alreadyfailed['times'] >= 10) {
+			throw new SoapFault('session_failure_limit', 'The Session failure limit has been reached.');
+			return false;
+		}
 
 		$sql = "SELECT * FROM remote_session WHERE remote_session = ? AND tstamp >= UNIX_TIMESTAMP()";
-		$session = $app->db->queryOneRecord($sql, $session_id);
+		$session = $app->db->queryOneRecord($sql, (string)$session_id);
+		
+		if(!is_array($session)) {
+			if(!$alreadyfailed['times'] )
+				{
+					//* user login the first time wrong
+					$sql = "INSERT INTO `attempts_login` (`ip`, `times`, `login_time`) VALUES (?, 1, NOW())";
+					$app->db->query($sql, $ip_md5);
+				} elseif($alreadyfailed['times'] >= 1) {
+					//* update times wrong
+					$sql = "UPDATE `attempts_login` SET `times`=`times`+1, `login_time`=NOW() WHERE `ip` = ? ORDER BY `login_time` DESC LIMIT 1";
+					$app->db->query($sql, $ip_md5);
+				}
+			
+			throw new SoapFault('session_does_not_exist', 'The Session is expired or does not exist.');
+			return false;
+		}
+		
+		$ip = $_SERVER['REMOTE_ADDR'];
+		if($session['remote_ip'] != $ip) {
+			throw new SoapFault('session_ip_mismatch', 'Session IP mismatch.');
+			return false;
+		}
+		
 		if($session['remote_userid'] > 0) {
 			return $session;
 		} else {
+			
+			if(!$alreadyfailed['times'] )
+				{
+					//* user login the first time wrong
+					$sql = "INSERT INTO `attempts_login` (`ip`, `times`, `login_time`) VALUES (?, 1, NOW())";
+					$app->db->query($sql, $ip_md5);
+				} elseif($alreadyfailed['times'] >= 1) {
+					//* update times wrong
+					$sql = "UPDATE `attempts_login` SET `times`=`times`+1, `login_time`=NOW() WHERE `ip` = ? AND `login_time` < NOW() ORDER BY `login_time` DESC LIMIT 1";
+					$app->db->query($sql, $ip_md5);
+				}
+			
 			throw new SoapFault('session_does_not_exist', 'The Session is expired or does not exist.');
 			return false;
 		}
@@ -553,7 +651,7 @@ class remoting {
 			return false;
 		}
 	}
-	
+
 	/**
 	    Gets a list of all servers
 	    @param int session_id
