@@ -175,7 +175,8 @@ class validate_client {
 				}
 			}
 			try {
-				$client = new SoapClient("http://ec.europa.eu/taxation_customs/vies/checkVatService.wsdl");
+				ini_set("default_socket_timeout", 5);
+				$client = new SoapClient("http://ec.europa.eu/taxation_customs/vies/checkVatService.wsdl", array('connection_timeout' => 5));
 				$params = array('countryCode' => $cc, 'vatNumber' => $vn);
 				try{
 					$r = $client->checkVat($params);
