@@ -64,8 +64,8 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 */
 
-$form["title"]    = "IP Addresses";
-$form["description"]  = "Form to edit system IP Addresses";
+$form["title"]    = "server_ip_edit_title";
+//$form["description"]  = "server_ip_edit_desc";
 $form["name"]    = "server_ip";
 $form["action"]   = "server_ip_edit.php";
 $form["db_table"]  = "server_ip";
