@@ -60,7 +60,7 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
 $form["title"]    = "Additional PHP Versions";
-$form["description"]  = "Form to edit additional PHP versions";
+//$form["description"]  = "Form to edit additional PHP versions";
 $form["name"]    = "server_php";
 $form["action"]   = "server_php_edit.php";
 $form["db_table"]  = "server_php";
@@ -174,7 +174,7 @@ $form["tabs"]['php_fastcgi'] = array(
 			'maxlength' => '255'
 		),
 		//#################################
-		// ENDE Datatable fields
+		// END Datatable fields
 		//#################################
 	)
 );
@@ -229,9 +229,39 @@ $form["tabs"]['php_fpm'] = array(
 			'width' => '40',
 			'maxlength' => '255'
 		),
+		'php_fpm_socket_dir' => array(
+			'datatype' => 'VARCHAR',
+			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
+			'default' => '',
+			'value' => '',
+			'width' => '40',
+			'maxlength' => '255'
+		),
 		//#################################
-		// ENDE Datatable fields
+		// END Datatable fields
 		//#################################
 	)
 );
+$form["tabs"]['php_sort'] = array (
+    	'title' => "PHP Sort Priority",
+	'width' => 80,
+	'template' => "templates/server_php_sort_edit.htm",
+	'fields' => array(
+                   'sortprio' => array (
+			'datatype' => 'INTEGER',
+			'formtype' => 'TEXT',
+			'default' => '100',
+			'value'  => '',
+			'separator' => '',
+			'width'  => '10',
+			'maxlength' => '20'
+		),
+	)
+);
 ?>
