@@ -1,4 +1,4 @@
-﻿<?php
+<?php
 /*
     Datatypes:
     - INTEGER
@@ -95,7 +95,7 @@ $liste["item"][] = array( 'field'  => "virtualhost",
 	'prefix' => "",
 	'suffix' => "",
 	'width'  => "",
-	'value'  => array('y' => "<div id=\"ir-Yes\" class=\"swap\"><span>".$app->lng('yes_txt')."</span></div>", 'n' => "<div class=\"swap\" id=\"ir-No\"><span>".$app->lng('no_txt')."</span></div>"));
+	'value'  => array('y' => $app->lng('yes_txt'), 'n' => $app->lng('no_txt')));
 
 
 $liste['item'][] = array( 'field'  => 'virtualhost_port',
