@@ -1,15 +1,15 @@
 <?php
 
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
 // Path to the list definition file
 $list_def_file = 'list/remote_user.list.php';
 
 // Check the module permissions
-if(!stristr($_SESSION['s']['user']['modules'],'admin')) {
-    header('Location: ../index.php');
-    die();
+if(!stristr($_SESSION['s']['user']['modules'], 'admin')) {
+	header('Location: ../index.php');
+	die();
 }
 
 // Loading the class
