@@ -31,45 +31,37 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 require_once '../lib/config.inc.php';
 require_once '../lib/app.inc.php';
 
+include_once 'common.php';
+
 //* Import module variable
 $mod = $_REQUEST["mod"];
 //* If we click on a search result, load that one instead of the module's start page
 $redirect = (isset($_REQUEST["redirect"]) ? $_REQUEST["redirect"] : '');
 
 //* Check if user is logged in
-if($_SESSION["s"]["user"]['active'] != 1) {
+if ($_SESSION["s"]["user"]['active'] != 1) {
 	die("URL_REDIRECT: /index.php");
 	//die();
 }
 
-if(!preg_match("/^[a-z]{2,20}$/i", $mod)) die('module name contains unallowed chars.');
-if($redirect != '' && !preg_match("/^[a-z0-9]+\/[a-z0-9_\.\-]+\?id=[0-9]{1,9}$/i", $redirect)) die('redirect contains unallowed chars.');
+if (!preg_match("/^[a-z]{2,20}$/i", $mod)) die('module name contains unallowed chars.');
+if ($redirect != '' && !preg_match("/^[a-z0-9]+\/[a-z0-9_\.\-]+\?id=[0-9]{1,9}(\&type=[a-z0-9_\.\-]+)?(\&next_tab=[a-z0-9_\.\-]+)?$/i", $redirect)) die('redirect contains unallowed chars.');
 
 //* Check if user may use the module.
 $user_modules = explode(",", $_SESSION["s"]["user"]["modules"]);
 
-if(!in_array($mod, $user_modules)) $app->error($app->lng(301));
+if (!in_array($mod, $user_modules)) $app->error($app->lng(301));
 
 //* Load module configuration into the session.
-if(is_file($mod."/lib/module.conf.php")) {
+if (is_file($mod."/lib/module.conf.php")) {
 	include_once $mod."/lib/module.conf.php";
 
-	$menu_dir = ISPC_WEB_PATH.'/' . $mod . '/lib/menu.d';
-
-	if (is_dir($menu_dir)) {
-		if ($dh = opendir($menu_dir)) {
-			//** Go through all files in the menu dir
-			while (($file = readdir($dh)) !== false) {
-				if ($file != '.' && $file != '..' && substr($file, -9, 9) == '.menu.php' && $file != 'dns_resync.menu.php') {
-					include_once $menu_dir . '/' . $file;
-				}
-			}
-		}
-	}
+	$menu_dir = ISPC_WEB_PATH.'/'.$mod.'/lib/menu.d';
+	include_menu_dir_files($menu_dir);
 
 	$_SESSION["s"]["module"] = $module;
 	session_write_close();
-	if($redirect == ''){
+	if ($redirect == '') {
 		echo "HEADER_REDIRECT:".$_SESSION["s"]["module"]["startpage"];
 	} else {
 		//* If we click on a search result, load that one instead of the module's start page
