@@ -41,11 +41,12 @@
 $form["title"]   = "Client";
 $form["description"]    = "";
 $form["name"]   = "client";
+$form["record_name_field"] = "username";
 $form["action"]  = "client_edit.php";
 $form["db_table"] = "client";
 $form["db_table_idx"] = "client_id";
 $form["db_history"] = "yes";
-$form["tab_default"] = "address";
+$form["tab_default"] = "info";
 $form["list_default"] = "client_list.php";
 $form["auth"]  = 'yes';
 
@@ -80,6 +81,12 @@ while ($file = @readdir($handle)) {
 	}
 }
 
+$form["tabs"]['info'] = array (
+	'title'  => "Info",
+	'width'  => 100,
+	'template'  => "templates/client_edit_info.htm",
+	'fields'  => array ()
+);
 $form["tabs"]['address'] = array (
 	'title'  => "Address",
 	'width'  => 100,
@@ -224,6 +231,9 @@ $form["tabs"]['address'] = array (
 		'language' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'SELECT',
+			'validators' => array ( 0 => array ( 'type' => 'NOTEMPTY',
+					'errmsg'=> 'language_error_empty'),
+			),
 			'default' => $conf["language"],
 			'value'  => $language_list,
 			'separator' => '',
@@ -318,7 +328,7 @@ $form["tabs"]['address'] = array (
 		'country' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'SELECT',
-			'default' => (isset($conf['language']) ? strtoupper($conf['language']) : ''),
+                       'default' => (isset($conf['default_country'])) ? strtoupper($conf['default_country']) : ((isset($conf['language'])) ? strtoupper($conf['language']) : ''),
 			'datasource' => array (  'type'          => 'SQL',
 				'querystring'   => 'SELECT iso,printable_name FROM country ORDER BY printable_name ASC',
 				'keyfield'      => 'iso',
@@ -390,8 +400,8 @@ $form["tabs"]['address'] = array (
 				2 => array( 'event' => 'SAVE',
 					'type' => 'TOLOWER')
 			),
-			'validators' => array (  
-				0 => array ( 'type' => 'ISEMAIL', 'errmsg'=> 'email_error_isemail'),
+			'validators' => array (
+				0 => array ( 'type' => 'ISEMAILADDRESS', 'errmsg'=> 'email_error_isemail'),
 				1 => array ( 'type' => 'NOTEMPTY',
 					'errmsg'=> 'email_error_empty'),
 			),
@@ -413,7 +423,7 @@ $form["tabs"]['address'] = array (
 					1 => array( 'event' => 'SAVE',
 					'type' => 'STRIPNL')
 			),
-			'default' => 'http://',
+			'default' => 'https://',
 			'value'  => '',
 			'separator' => '',
 			'width'  => '30',
@@ -422,6 +432,7 @@ $form["tabs"]['address'] = array (
 			'cols'  => '',
 			'searchable' => 2
 		),
+		// Deprecated
 		'icq' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
@@ -621,7 +632,7 @@ $form["tabs"]['address'] = array (
 					'type' => 'TOLOWER')
 			),
 			'validators' => array (
-				0 => array ( 'type' => 'ISEMAIL', 'allowempty' => 'y', 'errmsg'=> 'email_error_isemail'),
+				0 => array ( 'type' => 'ISEMAILADDRESS', 'allowempty' => 'y', 'errmsg'=> 'email_error_isemail'),
 			),
 			'default' => '',
 			'value'  => '',
@@ -840,6 +851,20 @@ $form["tabs"]['limits'] = array (
 			'rows'  => '',
 			'cols'  => ''
 		),
+		'limit_mail_wblist' => array (
+			'datatype' => 'INTEGER',
+			'formtype' => 'TEXT',
+			'validators' => array (  0 => array ( 'type' => 'ISINT',
+					'errmsg'=> 'limit_mail_wblist_error_notint'),
+			),
+			'default' => '-1',
+			'value'  => '',
+			'separator' => '',
+			'width'  => '10',
+			'maxlength' => '10',
+			'rows'  => '',
+			'cols'  => ''
+		),
 		'limit_mailfilter' => array (
 			'datatype' => 'INTEGER',
 			'formtype' => 'TEXT',
@@ -924,6 +949,20 @@ $form["tabs"]['limits'] = array (
 			'rows'  => '',
 			'cols'  => ''
 		),
+		'limit_mail_backup' => array (
+			'datatype' => 'VARCHAR',
+			'formtype' => 'CHECKBOX',
+			'default' => 'y',
+			'valuelimit' => 'client:limit_mail_backup',
+			'value'  => array(0 => 'n', 1 => 'y')
+		),
+		'limit_relayhost' => array (
+			'datatype' => 'VARCHAR',
+			'formtype' => 'CHECKBOX',
+			'default' => 'n',
+			'valuelimit' => 'client:limit_relayhost',
+			'value'  => array(0 => 'n', 1 => 'y')
+		),
         'default_xmppserver' => array (
             'datatype' => 'INTEGER',
             'formtype' => 'SELECT',
@@ -985,42 +1024,49 @@ $form["tabs"]['limits'] = array (
             'datatype' => 'VARCHAR',
             'formtype' => 'CHECKBOX',
             'default' => 'n',
+			'valuelimit' => 'client:limit_xmpp_muc',
             'value'  => array(0 => 'n', 1 => 'y')
         ),
         'limit_xmpp_anon' => array(
             'datatype' => 'VARCHAR',
             'formtype' => 'CHECKBOX',
             'default' => 'n',
+			'valuelimit' => 'client:limit_xmpp_anon',
             'value'  => array(0 => 'n', 1 => 'y')
         ),
         'limit_xmpp_vjud' => array(
             'datatype' => 'VARCHAR',
             'formtype' => 'CHECKBOX',
             'default' => 'n',
+			'valuelimit' => 'client:limit_xmpp_vjud',
             'value'  => array(0 => 'n', 1 => 'y')
         ),
         'limit_xmpp_proxy' => array(
             'datatype' => 'VARCHAR',
             'formtype' => 'CHECKBOX',
             'default' => 'n',
+			'valuelimit' => 'client:limit_xmpp_proxy',
             'value'  => array(0 => 'n', 1 => 'y')
         ),
         'limit_xmpp_status' => array(
             'datatype' => 'VARCHAR',
             'formtype' => 'CHECKBOX',
             'default' => 'n',
+			'valuelimit' => 'client:limit_xmpp_status',
             'value'  => array(0 => 'n', 1 => 'y')
         ),
         'limit_xmpp_pastebin' => array(
             'datatype' => 'VARCHAR',
             'formtype' => 'CHECKBOX',
             'default' => 'n',
+			'valuelimit' => 'client:limit_xmpp_pastebin',
             'value'  => array(0 => 'n', 1 => 'y')
         ),
         'limit_xmpp_httparchive' => array(
             'datatype' => 'VARCHAR',
             'formtype' => 'CHECKBOX',
             'default' => 'n',
+			'valuelimit' => 'client:limit_xmpp_httparchive',
             'value'  => array(0 => 'n', 1 => 'y')
         ),
 		'default_webserver' => array (
@@ -1087,67 +1133,77 @@ $form["tabs"]['limits'] = array (
 			),
 			'default' => '',
 			'separator' => ',',
-			'valuelimit' => 'system:sites:web_php_options',
+			'valuelimit' => 'system:sites:web_php_options;client:web_php_options',
 			'value'  => array('no' => 'Disabled', 'fast-cgi' => 'Fast-CGI', 'cgi' => 'CGI', 'mod' => 'Mod-PHP', 'suphp' => 'SuPHP', 'php-fpm' => 'PHP-FPM', 'hhvm' => 'HHVM')
 		),
 		'limit_cgi' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
 			'default' => 'n',
+			'valuelimit' => 'client:limit_cgi',
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'limit_ssi' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
 			'default' => 'n',
+			'valuelimit' => 'client:limit_ssi',
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'limit_perl' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
 			'default' => 'n',
+			'valuelimit' => 'client:limit_perl',
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'limit_ruby' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
 			'default' => 'n',
+			'valuelimit' => 'client:limit_ruby',
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'limit_python' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
 			'default' => 'n',
+			'valuelimit' => 'client:limit_python',
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'force_suexec' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
 			'default' => 'y',
+			'valuelimit' => 'client:force_suexec',
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'limit_hterror' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
 			'default' => 'n',
+			'valuelimit' => 'client:limit_hterror',
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'limit_wildcard' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
 			'default' => 'n',
+			'valuelimit' => 'client:limit_wildcard',
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'limit_ssl' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
 			'default' => 'n',
+			'valuelimit' => 'client:limit_ssl',
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'limit_ssl_letsencrypt' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
 			'default' => 'n',
+			'valuelimit' => 'client:limit_ssl_letsencrypt',
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'limit_web_aliasdomain' => array (
@@ -1235,12 +1291,14 @@ $form["tabs"]['limits'] = array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
 			'default' => 'y',
+			'valuelimit' => 'client:limit_backup',
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'limit_directive_snippets' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
 			'default' => 'n',
+			'valuelimit' => 'client:limit_directive_snippets',
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'default_dnsserver' => array (
@@ -1426,6 +1484,7 @@ $form["tabs"]['limits'] = array (
 			'datatype'  => 'VARCHAR',
 			'formtype'  => 'SELECT',
 			'default'   => '',
+			'valuelimit' => 'client:limit_cron_type',
 			'value'     => array('full' => 'Full Cron', 'chrooted' => 'Chrooted Cron', 'url' => 'URL Cron')
 		),
 		'limit_cron_frequency' => array (
@@ -1479,6 +1538,7 @@ $form["tabs"]['limits'] = array (
 				'keyfield'=> 'template_id',
 				'valuefield'=> 'template_name'
 			),
+			'valuelimit' => 'client:limit_openvz_vm_template_id',
 			'value'  => array(0 => ' ')
 		),
 		'limit_aps' => array (
@@ -1518,7 +1578,7 @@ $form["tabs"]['ipaddress'] = array (
 			'separator'	=> ';'
 		),
 	##################################
-	# ENDE Datatable fields
+	# END Datatable fields
 	##################################
 	)
 );
