@@ -112,10 +112,11 @@ $form["tabs"]['circle'] = array (
 			'default' => '',
 			'separator' => ',',
 			'datasource' => array (  'type' => 'SQL',
-				'querystring' => 'SELECT client_id,contact_name FROM client WHERE {AUTHSQL} ORDER BY contact_name',
+				'querystring' => 'SELECT client_id,CONCAT(company_name, " (",contact_firstname, " ", contact_name, ")") as contact_label FROM client WHERE {AUTHSQL} ORDER BY contact_label',
 				'keyfield'=> 'client_id',
-				'valuefield'=> 'contact_name'
+				'valuefield'=> 'contact_label'
 			),
+			'render_inline' => 'n',
 			'value'  => ''
 		),
 		'description' => array (
