@@ -1,6 +1,6 @@
 <?php
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
 /******************************************
 * Begin Form configuration
@@ -16,9 +16,10 @@ $list_def_file = "list/dns_soa.list.php";
 $app->auth->check_module_permissions('dns');
 
 $app->uses('listform_actions');
-// $app->listform_actions->SQLExtWhere = "access = 'REJECT'";
+// $app->listform_actions->SQLExtWhere = "dns_soa.access = 'REJECT'";
 
+$app->listform_actions->SQLOrderBy = 'ORDER BY dns_soa.origin';
 $app->listform_actions->onLoad();
 
 
-?>
\ No newline at end of file
+?>
