@@ -42,6 +42,7 @@ global $app;
 $form["title"]    = "DNS Zone";
 $form["description"]  = "";
 $form["name"]    = "dns_soa";
+$form["record_name_field"] = "origin";
 $form["action"]   = "dns_soa_edit.php";
 $form["db_table"]  = "dns_soa";
 $form["db_table_idx"] = "id";
@@ -56,8 +57,33 @@ $form["auth_preset"]["perm_user"] = 'riud'; //r = read, i = insert, u = update,
 $form["auth_preset"]["perm_group"] = 'riud'; //r = read, i = insert, u = update, d = delete
 $form["auth_preset"]["perm_other"] = ''; //r = read, i = insert, u = update, d = delete
 
+$form["tabs"]['dns_records'] = array (
+	'title'  => "Records",
+	'width'  => 100,
+	'template'  => "templates/dns_records_edit.htm",
+	'fields'  => array (
+		//#################################
+		// Begin Datatable fields
+		//#################################
+
+		//#################################
+		// END Datatable fields
+		//#################################
+	),
+	'plugins' => array (
+		'dns_records' => array (
+			'class'   => 'plugin_listview',
+			'options' => array(
+				'listdef' => 'list/dns_a.list.php',
+				'sqlextwhere' => "zone = ".@$app->functions->intval(@$_REQUEST['id']),
+				'sql_order_by' => "ORDER BY type, name"
+			)
+		)
+	)
+);
+
 $form["tabs"]['dns_soa'] = array (
-	'title'  => "DNS Zone",
+	'title'  => "Zone settings",
 	'width'  => 100,
 	'template'  => "templates/dns_soa_edit.htm",
 	'fields'  => array (
@@ -95,7 +121,7 @@ $form["tabs"]['dns_soa'] = array (
 				1 => array ( 'type' => 'UNIQUE',
 					'errmsg'=> 'origin_error_unique'),
 				2 => array ( 'type' => 'REGEX',
-					'regex' => '/^[a-zA-Z0-9\.\-\/]{2,255}\.[a-zA-Z0-9\-]{2,30}[\.]{0,1}$/',
+					'regex' => '/^[a-zA-Z0-9\.\-\/]{1,255}\.[a-zA-Z0-9\-]{2,63}[\.]{0,1}$/',
 					'errmsg'=> 'origin_error_regex'),
 			),
 			'default' => '',
@@ -219,18 +245,11 @@ $form["tabs"]['dns_soa'] = array (
 			'formtype' => 'TEXT',
 			'validators' => array (  0 => array ( 'type' => 'CUSTOM',
 					'class' => 'validate_dns',
-					'function' => 'validate_xfer',
+					'function' => 'validate_ip',
 					'allowempty' => 'y',
 					'separator' => ',',
 					'errmsg'=> 'xfer_error_regex'),
 			),
-			/*
-			'validators' => array (  0 => array ( 'type' => 'ISIP',
-					'allowempty' => 'y',
-					'separator' => ',',
-					'errmsg'=> 'xfer_error_regex'),
-			),
-			*/
 			'default' => '',
 			'value'  => '',
 			'width'  => '30',
@@ -239,7 +258,9 @@ $form["tabs"]['dns_soa'] = array (
 		'also_notify' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
-			'validators'    => array (  0 => array ( 'type' => 'ISIP',
+			'validators' => array (  0 => array ( 'type' => 'CUSTOM',
+					'class' => 'validate_dns',
+					'function' => 'validate_ip',
 					'allowempty' => 'y',
 					'separator' => ',',
 					'errmsg'=> 'also_notify_error_regex'
@@ -276,6 +297,16 @@ $form["tabs"]['dns_soa'] = array (
 			'default' => 'Y',
 			'value'  => array(0 => 'N', 1 => 'Y')
 		),
+		'dnssec_algo' => array (
+			'datatype' => 'VARCHAR',
+			'formtype' => 'CHECKBOXARRAY',
+			'separator' => ',',
+			'default' => 'ECDSAP256SHA256',
+			'value'  => array('NSEC3RSASHA1' => '7 (NSEC3RSASHA1)','ECDSAP256SHA256' => '13 (ECDSAP256SHA256)'),
+			'data-check-fields' => 'dnssec_wanted',
+			'width'  => '30',
+			'maxlength' => '255'
+		),
  		'dnssec_info' => array (
  			'datatype' => 'TEXT',
  			'formtype' => 'TEXTAREA',
@@ -289,35 +320,25 @@ $form["tabs"]['dns_soa'] = array (
  			'maxlength' => '10000'
  		),
 		//#################################
-		// ENDE Datatable fields
+		// END Datatable fields
 		//#################################
 	)
 );
 
-$form["tabs"]['dns_records'] = array (
-	'title'  => "Records",
-	'width'  => 100,
-	'template'  => "templates/dns_records_edit.htm",
-	'fields'  => array (
-		//#################################
-		// Begin Datatable fields
-		//#################################
-
-		//#################################
-		// ENDE Datatable fields
-		//#################################
-	),
-	'plugins' => array (
-		'dns_records' => array (
-			'class'   => 'plugin_listview',
-			'options' => array(
-				'listdef' => 'list/dns_a.list.php',
-				'sqlextwhere' => "zone = ".@$app->functions->intval(@$_REQUEST['id']),
-				'sql_order_by' => "ORDER BY type, name"
-			)
+$sys_config = $app->getconf->get_global_config('dns');
+if($sys_config['dns_show_zoneexport'] == 'y') {
+	$form["tabs"]['dns_rendered_zone'] = array (
+		'title'  => "Zone rendering",
+		'width'  => 100,
+		'template'  => "templates/dns_soa_rendered.htm",
+		'fields'  => array (
+			'rendered_zone' => array (
+				'datatype' => 'TEXT',
+				'formtype' => 'TEXTAREA',
+			),
 		)
-	)
-);
+	);
+}
 
 // show update acl to admins only.
 if(!$app->auth->is_admin()) unset($form["tabs"]['dns_soa']['fields']['update_acl']);
