@@ -7,10 +7,7 @@ require_once '../../lib/app.inc.php';
 $list_def_file = 'list/faq_sections_list.php';
 
 // Check the module permissions
-if(!stristr($_SESSION['s']['user']['modules'], 'help')) {
-	header('Location: ../index.php');
-	die();
-}
+$app->auth->check_module_permissions('admin');
 
 // Loading the class
 $app->uses('listform_actions');
