@@ -43,11 +43,11 @@ $app->tpl->setInclude('content_tpl', 'templates/password_reset.htm');
 
 $app->tpl_defaults();
 
-include ISPC_ROOT_PATH.'/web/login/lib/lang/'.$app->functions->check_language($_SESSION['s']['language']).'.lng';
+include ISPC_ROOT_PATH.'/web/login/lib/lang/'.$app->functions->check_language($conf['language']).'.lng';
 $app->tpl->setVar($wb);
 $continue = true;
 
-if(isset($_POST['username']) && $_POST['username'] != '' && $_POST['email'] != '' && $_POST['username'] != 'admin') {
+if(isset($_POST['username']) && is_string($_POST['username']) && $_POST['username'] != '' && isset($_POST['email']) && is_string($_POST['email']) && $_POST['email'] != '' && $_POST['username'] != 'admin') {
 	if(!preg_match("/^[\w\.\-\_]{1,64}$/", $_POST['username'])) {
 		$app->tpl->setVar("error", $wb['user_regex_error']);
 		$continue = false;
@@ -60,19 +60,20 @@ if(isset($_POST['username']) && $_POST['username'] != '' && $_POST['email'] != '
 	$username = $_POST['username'];
 	$email = $_POST['email'];
 
-	$client = $app->db->queryOneRecord("SELECT client.*, sys_user.lost_password_function, sys_user.lost_password_hash, IF(sys_user.lost_password_reqtime IS NOT NULL AND DATE_SUB(NOW(), INTERVAL 15 MINUTE) < sys_user.lost_password_reqtime, 1, 0) as `lost_password_wait` FROM client,sys_user WHERE client.username = ? AND client.email = ? AND client.client_id = sys_user.client_id", $username, $email);
+	if($continue) {
+		$client = $app->db->queryOneRecord("SELECT client.*, sys_user.lost_password_function, sys_user.lost_password_hash, IF(sys_user.lost_password_reqtime IS NOT NULL AND DATE_SUB(NOW(), INTERVAL 15 MINUTE) < sys_user.lost_password_reqtime, 1, 0) as `lost_password_wait` FROM client,sys_user WHERE client.username = ? AND client.email = ? AND client.client_id = sys_user.client_id", $username, $email);
+	}
 
-	if($client['lost_password_function'] == 0) {
+	if($client && $client['lost_password_function'] == 0) {
 		$app->tpl->setVar("error", $wb['lost_password_function_disabled_txt']);
-	} elseif($client['lost_password_wait'] == 1) {
+	} elseif($client && $client['lost_password_wait'] == 1) {
 		$app->tpl->setVar("error", $wb['lost_password_function_wait_txt']);
 	} elseif ($continue) {
 		if($client['client_id'] > 0) {
 			$username = $client['username'];
-			$password_hash = sha1(uniqid('ispc_pw'));
+			$password_hash = sha1(random_bytes(20));
 			$app->db->query("UPDATE sys_user SET lost_password_reqtime = NOW(), lost_password_hash = ? WHERE username = ?", $password_hash, $username);
-			$app->tpl->setVar("message", $wb['pw_reset_act']);
-			
+
 			$server_domain = (isset($_SERVER['SERVER_NAME']) ? $_SERVER['SERVER_NAME'] : $_SERVER['HTTP_HOST']);
 			if($server_domain == '_') {
 				$tmp = explode(':',$_SERVER["HTTP_HOST"]);
@@ -81,9 +82,9 @@ if(isset($_POST['username']) && $_POST['username'] != '' && $_POST['email'] != '
 			}
 			if(!isset($_SERVER['HTTPS']) || $_SERVER['HTTPS'] != 'on') $server_domain = 'http://' . $server_domain;
 			else $server_domain = 'https://' . $server_domain;
-			
+
 			if(isset($_SERVER['SERVER_PORT']) && $_SERVER['SERVER_PORT'] != '443') $server_domain .= ':' . $_SERVER['SERVER_PORT'];
-			
+
 			$app->uses('getconf,ispcmail');
 			$server_config_array = $app->getconf->get_global_config();
 			$mail_config = $server_config_array['mail'];
@@ -94,10 +95,14 @@ if(isset($_POST['username']) && $_POST['username'] != '' && $_POST['email'] != '
 			$app->ispcmail->setSender($mail_config['admin_mail'], $mail_config['admin_name']);
 			$app->ispcmail->setSubject($wb['pw_reset_act_mail_title']);
 			$app->ispcmail->setMailText($wb['pw_reset_act_mail_msg'].$server_domain . '/login/password_reset.php?username=' . urlencode($username) . '&hash=' . urlencode($password_hash));
-			$app->ispcmail->send(array($client['contact_name'] => $client['email']));
+			$send_result = $app->ispcmail->send(array($client['contact_name'] => $client['email']));
 			$app->ispcmail->finish();
 
-			$app->tpl->setVar("msg", $wb['pw_reset_act']);
+			if($send_result !== false) {
+				$app->tpl->setVar("msg", $wb['pw_reset_act']);
+			} else {
+				$app->tpl->setVar("error", $wb['pw_reset_error_smtp_connection']);
+			}
 		} else {
 			$app->tpl->setVar("error", $wb['pw_error']);
 		}
@@ -108,7 +113,7 @@ if(isset($_POST['username']) && $_POST['username'] != '' && $_POST['email'] != '
 		$app->tpl->setVar("error", $wb['user_regex_error']);
 		$continue = false;
 	}
-	
+
 	$username = $_GET['username'];
 	$hash = $_GET['hash'];
 
@@ -123,16 +128,14 @@ if(isset($_POST['username']) && $_POST['username'] != '' && $_POST['email'] != '
 	} elseif ($continue) {
 		if($client['client_id'] > 0) {
 			$server_config_array = $app->getconf->get_global_config();
-			$min_password_length = 8;
-			if(isset($server_config_array['misc']['min_password_length'])) $min_password_length = $server_config_array['misc']['min_password_length'];
-			
+			$min_password_length = $app->auth->get_min_password_length();
+
 			$new_password = $app->auth->get_random_password($min_password_length, true);
 			$new_password_encrypted = $app->auth->crypt_password($new_password);
 
 			$username = $client['username'];
 			$app->db->query("UPDATE sys_user SET passwort = ?, lost_password_hash = '', lost_password_reqtime = NULL WHERE username = ?", $new_password_encrypted, $username);
 			$app->db->query("UPDATE client SET password = ? WHERE username = ?", $new_password_encrypted, $username);
-			$app->tpl->setVar("message", $wb['pw_reset']);
 
 			$app->uses('getconf,ispcmail');
 			$mail_config = $server_config_array['mail'];
@@ -143,11 +146,18 @@ if(isset($_POST['username']) && $_POST['username'] != '' && $_POST['email'] != '
 			$app->ispcmail->setSender($mail_config['admin_mail'], $mail_config['admin_name']);
 			$app->ispcmail->setSubject($wb['pw_reset_mail_title']);
 			$app->ispcmail->setMailText($wb['pw_reset_mail_msg'].$new_password);
-			$app->ispcmail->send(array($client['contact_name'] => $client['email']));
+			$send_result = $app->ispcmail->send(array($client['contact_name'] => $client['email']));
 			$app->ispcmail->finish();
 
 			$app->plugin->raiseEvent('password_reset', true);
-			$app->tpl->setVar("msg", $wb['pw_reset']);
+
+			if($send_result !== false) {
+				$app->tpl->setVar("msg", $wb['pw_reset']);
+				$app->tpl->setInclude('content_tpl', 'templates/index.htm');
+			} else {
+				$app->tpl->setVar("error", $wb['pw_reset_error_smtp_connection']);
+			}
+
 		} else {
 			$app->tpl->setVar("error", $wb['pw_error']);
 		}
@@ -172,7 +182,10 @@ $app->tpl->setVar('base64_logo_height', $logo_dimensions[1].'px');
 $app->tpl->setVar('base64_logo_txt', $base64_logo_txt);
 
 // Title
-$app->tpl->setVar('company_name', $sys_config['company_name']. ' :: ');
+$sys_config = $app->getconf->get_global_config('misc');
+if (!empty($sys_config['company_name'])) {
+	$app->tpl->setVar('company_name', $sys_config['company_name']. ' :: ');
+}
 
 $app->tpl_defaults();
 $app->tpl->pparse();
