@@ -98,7 +98,7 @@ $form["tabs"]['blacklist'] = array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'SELECT',
 			'default' => 'y',
-			'value'  => array('recipient' => 'Recipient', 'sender' => 'Sender', 'client' => 'Client')
+			'value'  => array('recipient' => 'recipient_txt', 'sender' => 'sender_txt', 'client' => 'client_txt')
 		),
 		'active' => array (
 			'datatype' => 'VARCHAR',
@@ -107,10 +107,13 @@ $form["tabs"]['blacklist'] = array (
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		//#################################
-		// ENDE Datatable fields
+		// END Datatable fields
 		//#################################
 	)
 );
 
+if (! $app->auth->is_admin()) {
+	$form['tabs']['blacklist']['fields']['type']['value'] = array('recipient' => 'Recipient', 'sender' => 'Sender');
+}
 
 ?>
