@@ -88,6 +88,14 @@ $form["tabs"]['transport'] = array (
 				4 => array( 'event' => 'SAVE',
 					'type' => 'STRIPNL')
 			),
+			'validators' => array(
+				0 => array(
+					'type' => 'CUSTOM',
+					'class' => 'validate_mail_transport',
+					'function' => 'validate_domain',
+					'errmsg'=> 'domain_error_unique',
+				)
+			),
 			'default' => '',
 			'value'  => '',
 			'width'  => '30',
@@ -122,7 +130,7 @@ $form["tabs"]['transport'] = array (
 			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		//#################################
-		// ENDE Datatable fields
+		// END Datatable fields
 		//#################################
 	)
 );
