@@ -44,13 +44,14 @@ $global_config = $app->getconf->get_global_config();
 $backup_available = true;
 if(!$app->auth->is_admin()) {
 	$client_group_id = $_SESSION['s']['user']['default_group'];
-	$client = $app->db->queryOneRecord("SELECT limit_backup FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $client_group_id);
-	if($client['limit_backup'] != 'y') $backup_available = false;
+	$client = $app->db->queryOneRecord("SELECT limit_mail_backup FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $client_group_id);
+	if($client['limit_mail_backup'] != 'y') $backup_available = false;
 }
 
 $form["title"]    = "Mailbox";
 $form["description"]  = "";
 $form["name"]    = "mail_user";
+$form["record_name_field"] = "email";
 $form["action"]   = "mail_user_edit.php";
 $form["db_table"]  = "mail_user";
 $form["db_table_idx"] = "mailuser_id";
@@ -122,7 +123,8 @@ $form["tabs"]['mailuser'] = array(
 			'default' => '',
 			'value'   => '',
 			'width'   => '30',
-			'maxlength' => '255'
+			'maxlength' => '255',
+			'searchable' => 2
 		),
 		'password' => array (
 			'datatype' => 'VARCHAR',
@@ -165,7 +167,7 @@ $form["tabs"]['mailuser'] = array(
 					'regex' => '/^([0-9]{1,})$/',
 					'errmsg'=> 'quota_error_value'),
 			),
-			'default' => '-1',
+			'default' => '0',
 			'value'  => '',
 			'width'  => '30',
 			'maxlength' => '255'
@@ -181,13 +183,19 @@ $form["tabs"]['mailuser'] = array(
 					'type' => 'TOLOWER')
 			),
 			'validators' => array (  0 => array ( 'type' => 'REGEX',
-					'regex' => '/^(\w+[\w\.\-\+]*\w{0,}@\w+[\w.-]*\.[a-z\-]{2,10}){0,1}(,\s*\w+[\w\.\-\+]*\w{0,}@\w+[\w.-]*\.[a-z\-]{2,10}){0,}$/i',
+					'regex' => '/^(\w+[\w\.\-\+]*\w{0,}@\w+[\w.-]*\.[a-z\-]{2,63}){0,1}(,\s*\w+[\w\.\-\+]*\w{0,}@\w+[\w.-]*\.[a-z\-]{2,63}){0,}$/i',
 					'errmsg'=> 'cc_error_isemail'),
 			),
 			'default' => '',
 			'value'  => '',
 			'width'  => '30',
-			'maxlength' => '255'
+			'maxlength' => '65535'
+		),
+		'forward_in_lda' => array (
+			'datatype' => 'VARCHAR',
+			'formtype' => 'CHECKBOX',
+			'default' => 'n',
+			'value'  => array(0 => 'n', 1 => 'y')
 		),
 		'sender_cc' => array (
 			'datatype' => 'VARCHAR',
@@ -199,15 +207,39 @@ $form["tabs"]['mailuser'] = array(
 				2 => array( 'event' => 'SAVE',
 					'type' => 'TOLOWER')
 			),
-			'validators' => array (  0 => array ( 'type' => 'REGEX',
-					'regex'=>'/^(\w+[\w\.\-\+]*\w{0,}@\w+[\w.-]*\.[a-z\-]{2,10}){0,1}(,\s*\w+[\w\.\-\+]*\w{0,}@\w+[\w.-]*\.[a-z\-]{2,10}){0,}$/i',
+			'validators' => array (  0 => array ( 'type' => 'ISEMAILADDRESS',
+					'allowempty' => 'y',
 					'errmsg'=> 'sender_cc_error_isemail'),
 			),
 			'default' => '',
 			'value'  => '',
 			'width'  => '30',
-			'maxlength' => '255'
+			'maxlength' => '255',
+			'searchable' => 2
 		),
+	)
+);
+
+if($app->auth->is_admin()) {
+	$form["tabs"]['mailuser']['fields'] += array(
+			'imap_prefix' => array (
+				'datatype' => 'VARCHAR',
+				'formtype' => 'TEXT',
+				'filters'   => array(
+						0 => array( 'event' => 'SAVE',
+						'type' => 'STRIPTAGS'),
+						1 => array( 'event' => 'SAVE',
+						'type' => 'STRIPNL')
+				),
+				'default' => '',
+				'value'  => '',
+				'width'  => '30',
+				'maxlength' => '255',
+			),
+	);
+}
+
+$form["tabs"]['mailuser']['fields'] += array(
 		'maildir' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
@@ -292,6 +324,12 @@ $form["tabs"]['mailuser'] = array(
 			'default' => 'n',
 			'value'  => array(1 => 'y', 0 => 'n')
 		),
+		'disabledeliver' => array (
+			'datatype' => 'VARCHAR',
+			'formtype' => 'CHECKBOX',
+			'default' => 'n',
+			'value'  => array(1 => 'y', 0 => 'n')
+		),
 		'disableimap' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'CHECKBOX',
@@ -307,7 +345,6 @@ $form["tabs"]['mailuser'] = array(
 		//#################################
 		// END Datatable fields
 		//#################################
-	)
 );
 
 if($global_config['mail']['mail_password_onlyascii'] == 'y') {
@@ -360,20 +397,16 @@ if ($global_config['mail']['mailbox_show_autoresponder_tab'] === 'y') {
 			'autoresponder_start_date' => array (
 				'datatype' => 'DATETIME',
 				'formtype' => 'DATETIME',
-				'validators'=> array ( 
+				'validators'=> array (
 					0 => array ( 'type' => 'ISDATETIME',
 						'allowempty' => 'y',
 						'errmsg'=> 'autoresponder_start_date_is_no_date'),
-					1 => array ( 'type' => 'CUSTOM',
-						'class' => 'validate_autoresponder',
-						'function' => 'start_date',
-						'errmsg'=> 'autoresponder_start_date_is_required'),
 				)
 			),
 			'autoresponder_end_date' => array (
 				'datatype' => 'DATETIME',
 				'formtype' => 'DATETIME',
-				'validators'=> array (  
+				'validators'=> array (
 					0 => array ( 'type' => 'ISDATETIME',
 						'allowempty' => 'y',
 						'errmsg'=> 'autoresponder_end_date_is_no_date'),
@@ -402,9 +435,23 @@ if ($global_config['mail']['mailbox_show_mail_filter_tab'] === 'y') {
 			//#################################
 			'move_junk' => array (
 				'datatype' => 'VARCHAR',
-				'formtype' => 'CHECKBOX',
-				'default' => 'n',
-				'value'  => array(0 => 'n', 1 => 'y')
+				'formtype' => 'SELECT',
+				'default' => 'y',
+				'value' => array('y' => 'move_junk_y_txt', 'a' => 'move_junk_a_txt', 'n' => 'move_junk_n_txt'),
+			),
+			'purge_trash_days' => array (
+				'datatype' => 'VARCHAR',
+				'formtype' => 'TEXT',
+				'validators' => array (
+				),
+				'default' => '0',
+			),
+			'purge_junk_days' => array (
+				'datatype' => 'VARCHAR',
+				'formtype' => 'TEXT',
+				'validators' => array (
+				),
+				'default' => '0',
 			),
 			//#################################
 			// END Datatable fields
@@ -469,10 +516,10 @@ if ($backup_available) {
 				'datatype'      => 'INTEGER',
 				'formtype'      => 'SELECT',
 				'default'       => '',
-				'value'         => array('1' => '1', '2' => '2', '3' => '3', '4' => '4', '5' => '5', '6' => '6', '7' => '7', '8' => '8', '9' => '9', '10' => '10')
+				'value'			=> array('1' => '1', '2' => '2', '3' => '3', '4' => '4', '5' => '5', '6' => '6', '7' => '7', '8' => '8', '9' => '9', '10' => '10', '15' => '15', '20' => '20', '30' => '30')
 			),
 		##################################
-		# ENDE Datatable fields
+		# END Datatable fields
 		##################################
 		),
 		'plugins' => array (
