@@ -1,6 +1,6 @@
 <?php
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
 /******************************************
 * Begin Form configuration
@@ -18,9 +18,9 @@ $app->auth->check_module_permissions('mail');
 $app->uses('listform_actions');
 
 // Limit the results to alias domains
-$app->listform_actions->SQLExtWhere = "type = 'catchall'";
+$app->listform_actions->SQLExtWhere = "mail_forwarding.type = 'catchall'";
 
 $app->listform_actions->onLoad();
 
 
-?>
\ No newline at end of file
+?>
