@@ -8,7 +8,7 @@ require_once '../../lib/app.inc.php';
 
 if($conf['demo_mode'] == true) $app->error('This function is disabled in demo mode.');
 
-$app->load('json_handler,getconf');
+$app->load('remoting_handler_base,json_handler,getconf');
 
 $security_config = $app->getconf->get_security_config('permissions');
 if($security_config['remote_api_allowed'] != 'yes') die('Remote API is disabled in security settings.');
