@@ -6,7 +6,7 @@ require_once '../../lib/config.inc.php';
 $conf['start_session'] = false;
 require_once '../../lib/app.inc.php';
 
-$app->load('rest_handler,getconf');
+$app->load('remoting_handler_base,rest_handler,getconf');
 
 $security_config = $app->getconf->get_security_config('permissions');
 if($security_config['remote_api_allowed'] != 'yes') die('Remote API is disabled in security settings.');
