@@ -22,9 +22,9 @@ class list_action extends listform_actions {
 
 		$rec = parent::prepareDataRow($rec);
 
-		$rec['active'] = "<div id=\"ir-Yes\" class=\"swap\"><span>Yes</span></div>";
+		$rec['active'] = "Yes";
 		if ($rec['backup_interval'] === 'none') {
-			$rec['active']        = "<div class=\"swap\" id=\"ir-No\"><span>No</span></div>";
+			$rec['active']        = "No";
 			$rec['backup_copies'] = 0;
 		}
 
@@ -39,5 +39,5 @@ class list_action extends listform_actions {
 }
 
 $list = new list_action;
-$list->SQLExtWhere = "";
+$list->SQLExtWhere = "web_domain.type = 'vhost'";
 $list->onLoad();
