@@ -56,15 +56,28 @@ class list_action extends listform_actions {
 				$rec['used'] = $rec['used'][1];
 			}
 		}
+		/**
+		 * progres bar variables
+		 * soft value consists of null / array and raw value bug ?
+		 */
+		$soft = is_array($rec['soft']) || $rec['soft'] === null ? 0 : $rec['soft']; 
+		$rec['percentage'] = $soft != 0 ? round(($rec['used']/$soft)*100) : '-1';
+		$rec['progressbar'] = $rec['percentage'] > 100 ? 100 : $rec['percentage'];
 		$rec['used_sort'] = $rec['used'];
+		/**
+		 * Get digits from system_user for numeric sort
+		 */
+		preg_match('/(?P<digits>\d+)/',$rec['system_user'],$system_user_digits);
+		$rec['system_user_sort'] = $system_user_digits['digits'];
+		
 		if (!is_numeric($rec['soft'])) $rec['soft']=$rec['soft'][1];
 		if (!is_numeric($rec['hard'])) $rec['hard']=$rec['hard'][1];
 		if (!is_numeric($rec['files'])) $rec['files']=$rec['files'][1];
 		$rec['used']=$app->functions->formatBytes($rec['used']*1024);
 		$rec['soft']=$app->functions->formatBytes($rec['soft']*1024);
 		$rec['hard']=$app->functions->formatBytes($rec['hard']*1024);
-		if($rec['soft'] == "NAN") $rec['soft'] = $app->lng('unlimited');
-		if($rec['hard'] == "NAN") $rec['hard'] = $app->lng('unlimited');
+		if($rec['soft'] == "NAN") $rec['soft'] = $app->lng('unlimited_txt');
+		if($rec['hard'] == "NAN") $rec['hard'] = $app->lng('unlimited_txt');
 /*
 		if($rec['used'] > 1024) {
 			$rec['used'] = round($rec['used'] / 1024, 2).' MB';
@@ -84,8 +97,8 @@ class list_action extends listform_actions {
 			$rec['hard'] .= ' KB';
 		}
 
-		if($rec['soft'] == " KB") $rec['soft'] = $app->lng('unlimited');
-		if($rec['hard'] == " KB") $rec['hard'] = $app->lng('unlimited');
+		if($rec['soft'] == " KB") $rec['soft'] = $app->lng('unlimited_txt');
+		if($rec['hard'] == " KB") $rec['hard'] = $app->lng('unlimited_txt');
 */
 
 		/*
@@ -94,8 +107,8 @@ class list_action extends listform_actions {
 		if(!strstr($rec['hard'],'M') && !strstr($rec['hard'],'K')) $rec['hard'].= ' B';
 		*/
 /*
-		if($rec['soft'] == '0 B' || $rec['soft'] == '0 KB' || $rec['soft'] == '0') $rec['soft'] = $app->lng('unlimited');
-		if($rec['hard'] == '0 B' || $rec['hard'] == '0 KB' || $rec['hard'] == '0') $rec['hard'] = $app->lng('unlimited');
+		if($rec['soft'] == '0 B' || $rec['soft'] == '0 KB' || $rec['soft'] == '0') $rec['soft'] = $app->lng('unlimited_txt');
+		if($rec['hard'] == '0 B' || $rec['hard'] == '0 KB' || $rec['hard'] == '0') $rec['hard'] = $app->lng('unlimited_txt');
 */
 		//* The variable "id" contains always the index variable
 		$rec['id'] = $rec[$this->idx_key];
