@@ -32,6 +32,7 @@ try {
 		'autoresponder_start_date' => '',
 		'autoresponder_end_date' => '',
 		'autoresponder_text' => 'hallo',
+		'autoresponder_subject' => 'Out of office reply',
 		'move_junk' => 'n',
 		'custom_mailfilter' => 'spam',
 		'postfix' => 'n',
@@ -42,9 +43,9 @@ try {
 		'disablesmtp' => 'n'
 	);
 
-	$affected_rows = $client->mail_user_add($session_id, $client_id, $params);
+	$mailuser_id = $client->mail_user_add($session_id, $client_id, $params);
 
-	echo "New user: ".$affected_rows."<br>";
+	echo "New user: ".$mailuser_id."<br>";
 
 	if($client->logout($session_id)) {
 		echo 'Logged out.<br />';
