@@ -53,11 +53,14 @@ try {
 		'allow_override' => 'All',
 		'apache_directives' => '',
 		'php_open_basedir' => '/',
+		'pm' => 'ondemand',
 		'pm_max_requests' => 0,
 		'pm_process_idle_timeout' => 10,
 		'custom_php_ini' => '',
 		'backup_interval' => '',
 		'backup_copies' => 1,
+		'backup_format_web' => 'default',
+		'backup_format_db' => 'gzip',
 		'active' => 'y',
 		'traffic_quota_lock' => 'n',
 		'http_port' => '80',
