@@ -1,7 +1,7 @@
 <?php
 
 $username = 'admin';
-$password = 'admin';
+$password = 'admin1234';
 
 /*
 $soap_location = 'http://localhost:8080/ispconfig3_3.0.5/interface/web/remote/index.php';
@@ -9,8 +9,8 @@ $soap_uri = 'http://localhost:8080/ispconfig3_3.0.5/interface/web/remote/';
 */
 
 
-$soap_location = 'http://192.168.0.105:8080/remote/index.php';
-$soap_uri = 'http://192.168.0.105:8080/remote/';
+$soap_location = 'https://192.168.1.100:8080/remote/index.php';
+$soap_uri = 'https://192.168.1.100:8080/remote/';
 
 
 ?>
