@@ -2,6 +2,8 @@
 
 PATH=/sbin:/usr/sbin:/bin:/usr/bin:/usr/local/sbin:/usr/local/bin:/usr/X11R6/bin
 
+. /etc/profile
+
 if [ -f /usr/local/ispconfig/server/lib/php.ini ]; then
         PHPINIOWNER=`stat -c %U /usr/local/ispconfig/server/lib/php.ini`
         if [ $PHPINIOWNER == 'root' ] || [ $PHPINIOWNER == 'ispconfig'  ]; then
@@ -10,7 +12,7 @@ if [ -f /usr/local/ispconfig/server/lib/php.ini ]; then
 fi
 
 cd /usr/local/ispconfig/server
-/usr/bin/php -q \
+$(which php) -q \
     -d disable_classes= \
     -d disable_functions= \
     -d open_basedir= \
