@@ -49,7 +49,7 @@ class cronjob_quota_notify extends cronjob {
 
 	public function onRunJob() {
 		global $app, $conf;
-		
+
 		/* used for all monitor cronjobs */
 		$app->load('monitor_tools');
 		$this->_tools = new monitor_tools();
@@ -57,11 +57,25 @@ class cronjob_quota_notify extends cronjob {
 
 		$web_config = $app->getconf->get_server_config($conf['server_id'], 'web');
 
+		// Get client email and eventual reseller email in array
+		$clients = [];
+		$sql = "SELECT client.email,client.parent_client_id, sys_group.groupid FROM sys_group, client WHERE sys_group.client_id = client.client_id";
+		$records = $app->db->queryAllRecords($sql);
+		if(is_array($records)) {
+			foreach($records as $rec) {
+				$reseller = ($rec['parent_client_id'] > 0) ? $app->db->queryOneRecord("SELECT email FROM client WHERE client_id = ?", $rec['parent_client_id']) : '';
+				$clients[$rec['groupid']] = [
+					'email' => $rec['email'],
+					'reseller' => $reseller
+				];
+			}
+		}
+
 		//######################################################################################################
 		// enforce traffic quota (run only on the "master-server")
 		//######################################################################################################
 
-		if ($app->dbmaster == $app->db) {
+		if ($app->running_on_masterserver()) {
 
 			$global_config = $app->getconf->get_global_config('mail');
 
@@ -81,14 +95,23 @@ class cronjob_quota_notify extends cronjob {
 					$web_traffic = round($tmp['total_traffic_bytes']/1024/1024);
 
 					if($web_traffic_quota > 0 && $web_traffic > $web_traffic_quota) {
-						$app->dbmaster->datalogUpdate('web_domain', array("traffic_quota_lock" => 'y', "active" => 'n'), 'domain_id', $rec['domain_id']);
-						$app->log('Traffic quota for '.$rec['domain'].' exceeded. Disabling website.', LOGLEVEL_DEBUG);
-
+						//* Lock website
+						if ($web_config['overtraffic_disable_web'] == 'y') {
+							$app->dbmaster->datalogUpdate('web_domain', array("traffic_quota_lock" => 'y', "active" => 'n'), 'domain_id', $rec['domain_id']);
+							$app->log('Traffic quota for '.$rec['domain'].' exceeded. Disabling website.', LOGLEVEL_DEBUG);
+						}
+						else {
+							$app->log('Traffic quota for '.$rec['domain'].' exceeded.', LOGLEVEL_DEBUG);
+						}
 						//* Send traffic notifications
-						if($rec['traffic_quota_lock'] != 'y' && ($web_config['overtraffic_notify_admin'] == 'y' || $web_config['overtraffic_notify_client'] == 'y')) {
+						if($rec['traffic_quota_lock'] != 'y' && ($web_config['overtraffic_notify_admin'] == 'y' || $web_config['overtraffic_notify_reseller'] == 'y' || $web_config['overtraffic_notify_client'] == 'y')) {
 
 							$placeholders = array('{domain}' => $rec['domain'],
-								'{admin_mail}' => ($global_config['admin_mail'] != ''? $global_config['admin_mail'] : 'root'));
+								'{admin_mail}' => ($global_config['admin_mail'] != ''? $global_config['admin_mail'] : 'root'),
+								'{used}' => $web_traffic,
+								'{limit}' => $web_traffic_quota,
+								'{ratio}' => number_format(($web_traffic_quota > 0 ? $web_traffic/$web_traffic_quota : 0) * 100, 2, '.', '').'%'
+							);
 
 							$recipients = array();
 							//* send email to admin
@@ -96,16 +119,26 @@ class cronjob_quota_notify extends cronjob {
 								$recipients[] = $global_config['admin_mail'];
 							}
 
-							//* Send email to client
-							if($web_config['overtraffic_notify_client'] == 'y') {
-								$client_group_id = $rec["sys_groupid"];
-								$client = $app->db->queryOneRecord("SELECT client.email FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $client_group_id);
-								if($client['email'] != '') {
-									$recipients[] = $client['email'];
+							//* Send email to reseller
+							if($web_config['overtraffic_notify_reseller'] == 'y') {
+								if($clients[$rec['sys_groupid']]['reseller'] != '') {
+									$recipients[] = $clients[$rec['sys_groupid']]['reseller'];
 								}
 							}
 
-							$this->_tools->send_notification_email('web_traffic_notification', $placeholders, $recipients);
+							//* Send email to client
+							if($web_config['overtraffic_notify_client'] == 'y') {
+								if($clients[$rec['sys_groupid']]['email'] != '') {
+									$recipients[] = $clients[$rec['sys_groupid']]['email'];
+								}
+							}
+
+							if ($web_config['overtraffic_disable_web'] == 'y') {
+								$this->_tools->send_notification_email('web_traffic_notification', $placeholders, $recipients);
+							}
+							else {
+								$this->_tools->send_notification_email('web_traffic_notification_warn', $placeholders, $recipients);
+							}
 						}
 
 					} else {
@@ -126,7 +159,7 @@ class cronjob_quota_notify extends cronjob {
 		// send website quota warnings by email
 		//######################################################################################################
 
-		if ($app->dbmaster == $app->db) {
+		if ($app->running_on_masterserver()) {
 
 			$global_config = $app->getconf->get_global_config('mail');
 
@@ -196,13 +229,13 @@ class cronjob_quota_notify extends cronjob {
 						$rec['hard'] .= ' KB';
 					}
 
-					// send notifications only if 90% or more of the quota are used
-					if($used_ratio < 0.9) {
+					// send notifications only if the website is over the quota threshold
+					if($used_ratio <= $web_config['overquota_notify_threshold'] / 100) {
 						// reset notification date
-						if($rec['last_quota_notification']) $app->dbmaster->datalogUpdate('web_domain', array("last_quota_notification" => null), 'domain_id', $rec['domain_id']);
+						if($rec['last_quota_notification']) $app->db->query("UPDATE web_domain SET last_quota_notification=null WHERE domain_id=?", $rec['domain_id']);
 
 						// send notification - everything ok again
-						if($rec['last_quota_notification'] && $web_config['overquota_notify_onok'] == 'y' && ($web_config['overquota_notify_admin'] == 'y' || $web_config['overquota_notify_client'] == 'y')) {
+						if($rec['last_quota_notification'] && $web_config['overquota_notify_onok'] == 'y' && ($web_config['overquota_notify_admin'] == 'y' || $web_config['overquota_notify_reseller'] == 'y' || $web_config['overquota_notify_client'] == 'y')) {
 							$placeholders = array('{domain}' => $rec['domain'],
 								'{admin_mail}' => ($global_config['admin_mail'] != ''? $global_config['admin_mail'] : 'root'),
 								'{used}' => $rec['used'],
@@ -217,12 +250,17 @@ class cronjob_quota_notify extends cronjob {
 								$recipients[] = $global_config['admin_mail'];
 							}
 
+							//* Send email to reseller
+							if($web_config['overquota_notify_reseller'] == 'y') {
+								if($clients[$rec['sys_groupid']]['reseller'] != '') {
+									$recipients[] = $clients[$rec['sys_groupid']]['reseller'];
+								}
+							}
+
 							//* Send email to client
 							if($web_config['overquota_notify_client'] == 'y') {
-								$client_group_id = $rec["sys_groupid"];
-								$client = $app->db->queryOneRecord("SELECT client.email FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $client_group_id);
-								if($client['email'] != '') {
-									$recipients[] = $client['email'];
+								if($clients[$rec['sys_groupid']]['email'] != '') {
+									$recipients[] = $clients[$rec['sys_groupid']]['email'];
 								}
 							}
 							$this->_tools->send_notification_email('web_quota_ok_notification', $placeholders, $recipients);
@@ -235,8 +273,8 @@ class cronjob_quota_notify extends cronjob {
 						elseif($web_config['overquota_notify_freq'] > 0 && $rec['notified_before'] >= $web_config['overquota_notify_freq']) $send_notification = true;
 
 						//* Send quota notifications
-						if(($web_config['overquota_notify_admin'] == 'y' || $web_config['overquota_notify_client'] == 'y') && $send_notification == true) {
-							$app->dbmaster->datalogUpdate('web_domain', array("last_quota_notification" => array("SQL" => "CURDATE()")), 'domain_id', $rec['domain_id']);
+						if(($web_config['overquota_notify_admin'] == 'y' || $web_config['overquota_notify_reseller'] == 'y' || $web_config['overquota_notify_client'] == 'y') && $send_notification == true) {
+							$app->db->query("UPDATE web_domain SET last_quota_notification=? WHERE domain_id=?", date('Y-m-d'), $rec['domain_id']);
 
 							$placeholders = array('{domain}' => $rec['domain'],
 								'{admin_mail}' => ($global_config['admin_mail'] != ''? $global_config['admin_mail'] : 'root'),
@@ -252,12 +290,17 @@ class cronjob_quota_notify extends cronjob {
 								$recipients[] = $global_config['admin_mail'];
 							}
 
+							//* Send email to reseller
+							if($web_config['overquota_notify_reseller'] == 'y') {
+								if($clients[$rec['sys_groupid']]['reseller'] != '') {
+									$recipients[] = $clients[$rec['sys_groupid']]['reseller'];
+								}
+							}
+
 							//* Send email to client
 							if($web_config['overquota_notify_client'] == 'y') {
-								$client_group_id = $rec["sys_groupid"];
-								$client = $app->db->queryOneRecord("SELECT client.email FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $client_group_id);
-								if($client['email'] != '') {
-									$recipients[] = $client['email'];
+								if($clients[$rec['sys_groupid']]['email'] != '') {
+									$recipients[] = $clients[$rec['sys_groupid']]['email'];
 								}
 							}
 							$this->_tools->send_notification_email('web_quota_notification', $placeholders, $recipients);
@@ -272,7 +315,7 @@ class cronjob_quota_notify extends cronjob {
 		// send mail quota warnings by email
 		//######################################################################################################
 
-		if ($app->dbmaster == $app->db) {
+		if ($app->running_on_masterserver()) {
 
 			$global_config = $app->getconf->get_global_config('mail');
 			$mail_config = $app->getconf->get_server_config($conf['server_id'], 'mail');
@@ -325,13 +368,13 @@ class cronjob_quota_notify extends cronjob {
 						$rec['used'] = round($rec['used'] / 1048576, 4).' MB';
 					}
 
-					// send notifications only if 90% or more of the quota are used
-					if($used_ratio < 0.9) {
+					// send notifications only if the mail account is over the quota threshold
+					if($used_ratio <= $mail_config['overquota_notify_threshold'] / 100) {
 						// reset notification date
-						if($rec['last_quota_notification']) $app->dbmaster->datalogUpdate('mail_user', array("last_quota_notification" => null), 'mailuser_id', $rec['mailuser_id']);
+						if($rec['last_quota_notification']) $app->db->query("UPDATE mail_user SET last_quota_notification=null WHERE mailuser_id=?", $rec['mailuser_id']);
 
 						// send notification - everything ok again
-						if($rec['last_quota_notification'] && $mail_config['overquota_notify_onok'] == 'y' && ($mail_config['overquota_notify_admin'] == 'y' || $mail_config['overquota_notify_client'] == 'y')) {
+						if($rec['last_quota_notification'] && $mail_config['overquota_notify_onok'] == 'y' && ($mail_config['overquota_notify_admin'] == 'y' || $web_config['overquota_notify_reseller'] == 'y' || $mail_config['overquota_notify_client'] == 'y')) {
 							$placeholders = array('{email}' => $rec['email'],
 								'{admin_mail}' => ($global_config['admin_mail'] != ''? $global_config['admin_mail'] : 'root'),
 								'{used}' => $rec['used'],
@@ -345,12 +388,17 @@ class cronjob_quota_notify extends cronjob {
 								$recipients[] = $global_config['admin_mail'];
 							}
 
+							//* Send email to reseller
+							if($web_config['overquota_notify_reseller'] == 'y') {
+								if($clients[$rec['sys_groupid']]['reseller'] != '') {
+									$recipients[] = $clients[$rec['sys_groupid']]['reseller'];
+								}
+							}
+
 							//* Send email to client
 							if($mail_config['overquota_notify_client'] == 'y') {
-								$client_group_id = $rec["sys_groupid"];
-								$client = $app->db->queryOneRecord("SELECT client.email FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $client_group_id);
-								if($client['email'] != '') {
-									$recipients[] = $client['email'];
+								if($clients[$rec['sys_groupid']]['email'] != '') {
+									$recipients[] = $clients[$rec['sys_groupid']]['email'];
 								}
 							}
 
@@ -364,8 +412,8 @@ class cronjob_quota_notify extends cronjob {
 						if(!$rec['last_quota_notification']) $send_notification = true; // not yet notified
 						elseif($mail_config['overquota_notify_freq'] > 0 && $rec['notified_before'] >= $mail_config['overquota_notify_freq']) $send_notification = true;
 
-						if(($mail_config['overquota_notify_admin'] == 'y' || $mail_config['overquota_notify_client'] == 'y') && $send_notification == true) {
-							$app->dbmaster->datalogUpdate('mail_user', array("last_quota_notification" => array("SQL" => "CURDATE()")), 'mailuser_id', $rec['mailuser_id']);
+						if(($mail_config['overquota_notify_admin'] == 'y' || $mail_config['overquota_notify_reseller'] == 'y' || $mail_config['overquota_notify_client'] == 'y') && $send_notification == true) {
+							$app->db->query("UPDATE mail_user SET last_quota_notification=? WHERE mailuser_id=?", date('Y-m-d'), $rec['mailuser_id']);
 
 							$placeholders = array('{email}' => $rec['email'],
 								'{admin_mail}' => ($global_config['admin_mail'] != ''? $global_config['admin_mail'] : 'root'),
@@ -380,12 +428,17 @@ class cronjob_quota_notify extends cronjob {
 								$recipients[] = $global_config['admin_mail'];
 							}
 
+							//* Send email to reseller
+							if($web_config['overquota_notify_reseller'] == 'y') {
+								if($clients[$rec['sys_groupid']]['reseller'] != '') {
+									$recipients[] = $clients[$rec['sys_groupid']]['reseller'];
+								}
+							}
+
 							//* Send email to client
 							if($mail_config['overquota_notify_client'] == 'y') {
-								$client_group_id = $rec["sys_groupid"];
-								$client = $app->db->queryOneRecord("SELECT client.email FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $client_group_id);
-								if($client['email'] != '') {
-									$recipients[] = $client['email'];
+								if($clients[$rec['sys_groupid']]['email'] != '') {
+									$recipients[] = $clients[$rec['sys_groupid']]['email'];
 								}
 							}
 
@@ -400,7 +453,7 @@ class cronjob_quota_notify extends cronjob {
 		// send database quota warnings by email
 		//######################################################################################################
 
-		if ($app->dbmaster == $app->db) {
+		if ($app->running_on_masterserver()) {
 
 			$global_config = $app->getconf->get_global_config('mail');
 
@@ -410,12 +463,12 @@ class cronjob_quota_notify extends cronjob {
 				$monitor_data = array();
 				foreach ($tmp_rec as $tmp_mon) {
 					$tmp_array = unserialize($app->db->unquote($tmp_mon['data']));
-					if(is_array($tmp_array)) 
+					if(is_array($tmp_array))
 						foreach($tmp_array as $sys_groupid => $data)
 							$monitor_data[$data['sys_groupid']][] = $data;
 				}
 				//* remove duplicates from monitor-data
-				foreach($monitor_data as $_monitor_data) 
+				foreach($monitor_data as $_monitor_data)
 					$monitor_data[$_monitor_data[0]['sys_groupid']]=array_map("unserialize", array_unique(array_map("serialize", $_monitor_data)));
 			}
 
@@ -434,15 +487,12 @@ class cronjob_quota_notify extends cronjob {
 						foreach($cid as $monitor) {
 
 							if ($monitor['database_name'] == $database) {
-								//* get the client
-								$client = $app->db->queryOneRecord("SELECT client.username, client.email FROM web_database, sys_group, client WHERE web_database.sys_groupid = sys_group.groupid AND sys_group.client_id = client.client_id AND web_database.database_name=?", $database);
-
 								//* check quota
 								if ($quota > 0) $used_ratio = $monitor['size'] / $quota;
 								else $used_ratio = 0;
 
-								//* send notifications only if 90% or more of the quota are used
-								if($used_ratio > 0.9 && $used_ratio != 0) {
+								//* send notifications only if the database is over the quota threshold
+								if($used_ratio >= $web_config['overquota_db_notify_threshold'] / 100 && $used_ratio != 0) {
 
 									//* could a notification be sent?
 									$send_notification = false;
@@ -451,8 +501,8 @@ class cronjob_quota_notify extends cronjob {
 
 
 									//* Send quota notifications
-									if(($web_config['overquota_db_notify_admin'] == 'y' || $web_config['overquota_db_notify_client'] == 'y') && $send_notification == true) {
-										$app->dbmaster->datalogUpdate('web_database', array("last_quota_notification" => array("SQL" => "CURDATE()")), 'database_id', $rec['database_id']);
+									if(($web_config['overquota_db_notify_admin'] == 'y' || $web_config['overquota_db_notify_reseller'] == 'y' || $web_config['overquota_db_notify_client'] == 'y') && $send_notification == true) {
+										$app->db->query("UPDATE web_database SET last_quota_notification=? WHERE database_id=?", date('Y-m-d'), $rec['database_id']);
 										$placeholders = array(
 											'{database_name}' => $rec['database_name'],
 											'{admin_mail}' => ($global_config['admin_mail'] != ''? $global_config['admin_mail'] : 'root'),
@@ -467,20 +517,29 @@ class cronjob_quota_notify extends cronjob {
 										if($global_config['admin_mail'] != '' && $web_config['overquota_db_notify_admin'] == 'y')
 											$recipients[] = $global_config['admin_mail'];
 
+										//* Send email to reseller
+										if($web_config['overquota_db_notify_reseller'] == 'y') {
+											if($clients[$rec['sys_groupid']]['reseller'] != '') {
+												$recipients[] = $clients[$rec['sys_groupid']]['reseller'];
+											}
+										}
+										
 										//* Send email to client
-										if($web_config['overquota_db_notify_client'] == 'y' && $client['email'] != '')
-											$recipients[] = $client['email'];
-
+										if($web_config['overquota_db_notify_client'] == 'y') {
+											if($clients[$rec['sys_groupid']]['email'] != '') {
+												$recipients[] = $clients[$rec['sys_groupid']]['email'];
+											}
+										}
 										$this->_tools->send_notification_email('db_quota_notification', $placeholders, $recipients);
 
 									}
 
 								} else {
 									//* reset notification date
-									if($rec['last_quota_notification']) $app->dbmaster->datalogUpdate('web_database', array("last_quota_notification" => null), 'database_id', $rec['database_id']);
+									if($rec['last_quota_notification']) $app->db->query("UPDATE web_database SET last_quota_notification=null WHERE database_id=?", $rec['database_id']);
 
 									// send notification - everything ok again
-									if($rec['last_quota_notification'] && $web_config['overquota_notify_onok'] == 'y' && ($web_config['overquota_db_notify_admin'] == 'y' || $web_config['overquota_db_notify_client'] == 'y')) {
+									if($rec['last_quota_notification'] && $web_config['overquota_notify_onok'] == 'y' && ($web_config['overquota_db_notify_admin'] == 'y' || $web_config['overquota_db_notify_reseller'] == 'y' || $web_config['overquota_db_notify_client'] == 'y')) {
 										$placeholders = array(
 											'{database_name}' => $rec['database_name'],
 											'{admin_mail}' => ($global_config['admin_mail'] != ''? $global_config['admin_mail'] : 'root'),
@@ -492,13 +551,23 @@ class cronjob_quota_notify extends cronjob {
 										$recipients = array();
 
 										//* send email to admin
-										if($global_config['admin_mail'] != '' && $web_config['overquota_db_notify_admin'] == 'y') 
+										if($global_config['admin_mail'] != '' && $web_config['overquota_db_notify_admin'] == 'y') {
 											$recipients[] = $global_config['admin_mail'];
+										}
+
+										//* Send email to reseller
+										if($web_config['overquota_db_notify_reseller'] == 'y') {
+											if($clients[$rec['sys_groupid']]['reseller'] != '') {
+												$recipients[] = $clients[$rec['sys_groupid']]['reseller'];
+											}
+										}
 
 										//* Send email to client
-										if($web_config['overquota_db_notify_client'] == 'y' && $client['email'] != '') 
-											$recipients[] = $client['email'];
-
+										if($mail_config['overquota_notify_client'] == 'y') {
+											if($clients[$rec['sys_groupid']]['email'] != '') {
+												$recipients[] = $clients[$rec['sys_groupid']]['email'];
+											}
+										}
 										$this->_tools->send_notification_email('db_quota_ok_notification', $placeholders, $recipients);
 
 									}
@@ -507,7 +576,7 @@ class cronjob_quota_notify extends cronjob {
 
 							}
 
-						}   
+						}
 
 					}
 
