@@ -101,16 +101,11 @@ class mysql_clientdb_plugin {
 
 		$success = true;
 		if(!preg_match('/\*[A-F0-9]{40}$/', $database_password)) {
-				$result = $link->query("SELECT PASSWORD('" . $link->escape_string($database_password) . "') as `crypted`");
-				if($result) {
-						$row = $result->fetch_assoc();
-						$database_password = $row['crypted'];
-						$result->free();
-				}
+				$database_password = $app->db->getPasswordHash($password);
 		}
-		
+
 		$app->log("Calling $action for $database_name with access $user_access_mode and hosts " . implode(', ', $host_list), LOGLEVEL_DEBUG);
-		
+
 		// loop through hostlist
 		foreach($host_list as $db_host) {
 			$db_host = trim($db_host);
@@ -137,22 +132,53 @@ class mysql_clientdb_plugin {
 				$app->log("Invalid host " . $db_host . " for GRANT to " . $database_name, LOGLEVEL_DEBUG);
 				continue;
 			}
-			
+
 			$grants = 'ALL PRIVILEGES';
 			if($user_access_mode == 'r') $grants = 'SELECT';
 			elseif($user_access_mode == 'rd') $grants = 'SELECT, DELETE, ALTER, DROP';
-			
+
+			$database_name = $link->escape_string($database_name);
+
 			if($action == 'GRANT') {
 				if($user_access_mode == 'r' || $user_access_mode == 'rd') {
-					if(!$link->query("REVOKE ALL PRIVILEGES ON `".$link->escape_string($database_name)."`.* FROM '".$link->escape_string($database_user)."'@'$db_host'")) $success = false;
-					$app->log("REVOKE ALL PRIVILEGES ON `".$link->escape_string($database_name)."`.* FROM '".$link->escape_string($database_user)."'@'$db_host' success? " . ($success ? 'yes' : 'no'), LOGLEVEL_DEBUG);
+					if(!$link->query("REVOKE ALL PRIVILEGES ON `".$database_name."`.* FROM '".$link->escape_string($database_user)."'@'$db_host'")) $success = false;
+					$app->log("REVOKE ALL PRIVILEGES ON `".$database_name."`.* FROM '".$link->escape_string($database_user)."'@'$db_host' success? " . ($success ? 'yes' : 'no'), LOGLEVEL_DEBUG);
 					$success = true;
 				}
-				
-				if(!$link->query("GRANT " . $grants . " ON `".$link->escape_string($database_name)."`.* TO '".$link->escape_string($database_user)."'@'$db_host' IDENTIFIED BY PASSWORD '".$link->escape_string($database_password)."'")) $success = false;
-				$app->log("GRANT " . $grants . " ON `".$link->escape_string($database_name)."`.* TO '".$link->escape_string($database_user)."'@'$db_host' IDENTIFIED BY PASSWORD '".$link->escape_string($database_password)."' success? " . ($success ? 'yes' : 'no'), LOGLEVEL_DEBUG);
-			} elseif($action == 'REVOKE') {
-				if(!$link->query("REVOKE ALL PRIVILEGES ON `".$link->escape_string($database_name)."`.* FROM '".$link->escape_string($database_user)."'@'$db_host'")) $success = false;
+
+				// Create the user
+				$link->query("CREATE USER '".$link->escape_string($database_user)."'@'$db_host'");
+				$app->log("CREATE USER '".$link->escape_string($database_user)."'@'$db_host'", LOGLEVEL_DEBUG);
+
+				// mariadb or mysql < 5.7
+				if($this->getDatabaseType($link) == 'mariadb' || version_compare($this->getDatabaseVersion($link), '5.7', '<')) {
+					$query = sprintf("SET PASSWORD FOR '%s'@'%s' = '%s'",
+						$link->escape_string($database_user),
+						$db_host,
+						$link->escape_string($database_password));
+					if(!$link->query($query)) $success = false;
+				}
+				// mysql >= 5.7
+				else {
+					$query = sprintf("ALTER USER IF EXISTS '%s'@'%s' IDENTIFIED WITH mysql_native_password AS '%s'",
+						$link->escape_string($database_user),
+						$db_host,
+						$link->escape_string($database_password));
+					if(!$link->query($query)) $success = false;
+				}
+
+				$app->log("PASSWORD SET FOR '".$link->escape_string($database_user)."'@'$db_host' success? " . ($success ? 'yes' : 'no'), LOGLEVEL_DEBUG);
+
+				if($success == true){
+					$link->query("FLUSH PRIVILEGES");
+				}
+
+				// Set the grant
+				if(!$link->query("GRANT " . $grants . " ON `".$database_name."`.* TO '".$link->escape_string($database_user)."'@'$db_host'")) $success = false;
+				$app->log("GRANT " . $grants . " ON `".$database_name."`.* TO '".$link->escape_string($database_user)."'@'$db_host' success? " . ($success ? 'yes' : 'no'), LOGLEVEL_DEBUG);
+
+				} elseif($action == 'REVOKE') {
+				if(!$link->query("REVOKE ALL PRIVILEGES ON `".$database_name."`.* FROM '".$link->escape_string($database_user)."'@'$db_host'")) $success = false;
 			} elseif($action == 'DROP') {
 				if(!$link->query("DROP USER '".$link->escape_string($database_user)."'@'$db_host'")) $success = false;
 			} elseif($action == 'RENAME') {
@@ -161,10 +187,21 @@ class mysql_clientdb_plugin {
 				//if(!$link->query("SET PASSWORD FOR '".$link->escape_string($database_user)."'@'$db_host' = '".$link->escape_string($database_password)."'")) $success = false;
 				// SET PASSWORD for already hashed passwords is not supported by latest MySQL 5.7 anymore, so we have to set the hashed password directly
 				if(trim($database_password) != '') {
-					// MySQL < 5.7 and MariadB 10
-					if(!$link->query("UPDATE mysql.user SET `Password` = '".$link->escape_string($database_password)."' WHERE `Host` = '".$db_host."' AND `User` = '".$link->escape_string($database_user)."'")) {
-						// MySQL 5.7, the Password field has been renamed to authentication_string
-						if(!$link->query("UPDATE mysql.user SET `authentication_string` = '".$link->escape_string($database_password)."' WHERE `Host` = '".$db_host."' AND `User` = '".$link->escape_string($database_user)."'")) $success = false;
+					// mariadb or mysql < 5.7
+					if($this->getDatabaseType($link) == 'mariadb' || version_compare($this->getDatabaseVersion($link), '5.7', '<')) {
+						$query = sprintf("SET PASSWORD FOR '%s'@'%s' = '%s'",
+							$link->escape_string($database_user),
+							$db_host,
+							$link->escape_string($database_password));
+						if(!$link->query($query)) $success = false;
+					}
+					// mysql >= 5.7
+					else {
+						$query = sprintf("ALTER USER IF EXISTS '%s'@'%s' IDENTIFIED WITH mysql_native_password AS '%s'",
+							$link->escape_string($database_user),
+							$db_host,
+							$link->escape_string($database_password));
+						if(!$link->query($query)) $success = false;
 					}
 					if($success == true) $link->query("FLUSH PRIVILEGES");
 				}
@@ -224,6 +261,7 @@ class mysql_clientdb_plugin {
 				return;
 			}
 
+			mysqli_report(MYSQLI_REPORT_OFF);
 			//* Connect to the database
 			$link = new mysqli($clientdb_host, $clientdb_user, $clientdb_password);
 			if ($link->connect_error) {
@@ -242,7 +280,7 @@ class mysql_clientdb_plugin {
 			if ($link->query('CREATE DATABASE `'.$link->escape_string($data['new']['database_name']).'`'.$query_charset_table)) {
 				$app->log('Created MySQL database: '.$data['new']['database_name'], LOGLEVEL_DEBUG);
 			} else {
-				$app->log('Unable to create the database: '.$link->error, LOGLEVEL_WARNING);
+				$app->log('Unable to create the database: '.$link->error, LOGLEVEL_WARN);
 			}
 
 			// Create the database user if database is active
@@ -261,11 +299,11 @@ class mysql_clientdb_plugin {
 				$host_list .= 'localhost';
 
 				if($db_user) {
-					if($db_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+					if($db_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 					else $this->process_host_list('GRANT', $data['new']['database_name'], $db_user['database_user'], $db_user['database_password'], $host_list, $link, '', ($data['new']['quota_exceeded'] == 'y' ? 'rd' : 'rw'));
 				}
 				if($db_ro_user && $data['new']['database_user_id'] != $data['new']['database_ro_user_id']) {
-					if($db_ro_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+					if($db_ro_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 					else $this->process_host_list('GRANT', $data['new']['database_name'], $db_ro_user['database_user'], $db_ro_user['database_password'], $host_list, $link, '', 'r');
 				}
 
@@ -287,13 +325,14 @@ class mysql_clientdb_plugin {
 				return;
 			}
 
+			mysqli_report(MYSQLI_REPORT_OFF);
 			//* Connect to the database
 			$link = new mysqli($clientdb_host, $clientdb_user, $clientdb_password);
 			if ($link->connect_error) {
 				$app->log('Unable to connect to the database: '.$link->connect_error, LOGLEVEL_ERROR);
 				return;
 			}
-			
+
 			// check if the database exists
 			if($data['new']['database_name'] == $data['old']['database_name']) {
 				$result = $link->query("SHOW DATABASES LIKE '".$link->escape_string($data['new']['database_name'])."'");
@@ -452,17 +491,17 @@ class mysql_clientdb_plugin {
 			// Create the database user if database was disabled before
 			if($data['new']['active'] == 'y') {
 				if($db_user) {
-					if($db_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+					if($db_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 					else $this->process_host_list('GRANT', $data['new']['database_name'], $db_user['database_user'], $db_user['database_password'], $host_list, $link, '', ($data['new']['quota_exceeded'] == 'y' ? 'rd' : 'rw'));
 				}
 				if($db_ro_user && $data['new']['database_user_id'] != $data['new']['database_ro_user_id']) {
-					if($db_ro_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+					if($db_ro_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 					else $this->process_host_list('GRANT', $data['new']['database_name'], $db_ro_user['database_user'], $db_ro_user['database_password'], $host_list, $link, '', 'r');
 				}
 			} elseif($data['new']['active'] == 'n' && $data['old']['active'] == 'y') { // revoke database user, if inactive
 				if($old_db_user) {
 					if($old_db_user['database_user'] == 'root'){
-						$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+						$app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 					} else {
 						// Find out users to drop and users to revoke
 						$drop_or_revoke_user = $this->drop_or_revoke_user($data['old']['database_id'], $data['old']['database_user_id'], $old_host_list);
@@ -473,7 +512,7 @@ class mysql_clientdb_plugin {
 				}
 				if($old_db_ro_user && $data['old']['database_user_id'] != $data['old']['database_ro_user_id']) {
 					if($old_db_ro_user['database_user'] == 'root'){
-						$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+						$app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 					} else {
 						// Find out users to drop and users to revoke
 						$drop_or_revoke_user = $this->drop_or_revoke_user($data['old']['database_id'], $data['old']['database_ro_user_id'], $old_host_list);
@@ -491,7 +530,7 @@ class mysql_clientdb_plugin {
 				if($data['old']['database_user_id'] && $data['old']['database_user_id'] != $data['new']['database_ro_user_id']) {
 					if($old_db_user) {
 						if($old_db_user['database_user'] == 'root'){
-							$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+							$app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 						} else {
 							// Find out users to drop and users to revoke
 							$drop_or_revoke_user = $this->drop_or_revoke_user($data['old']['database_id'], $data['old']['database_user_id'], $old_host_list);
@@ -501,7 +540,7 @@ class mysql_clientdb_plugin {
 					}
 				}
 				if($db_user) {
-					if($db_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+					if($db_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 					else $this->process_host_list('GRANT', $data['new']['database_name'], $db_user['database_user'], $db_user['database_password'], $host_list, $link, '', ($data['new']['quota_exceeded'] == 'y' ? 'rd' : 'rw'));
 				}
 			}
@@ -509,7 +548,7 @@ class mysql_clientdb_plugin {
 				if($data['old']['database_ro_user_id'] && $data['old']['database_ro_user_id'] != $data['new']['database_user_id']) {
 					if($old_db_ro_user) {
 						if($old_db_ro_user['database_user'] == 'root'){
-							$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+							$app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 						} else {
 							// Find out users to drop and users to revoke
 							$drop_or_revoke_user = $this->drop_or_revoke_user($data['old']['database_id'], $data['old']['database_ro_user_id'], $old_host_list);
@@ -519,7 +558,7 @@ class mysql_clientdb_plugin {
 					}
 				}
 				if($db_ro_user && $data['new']['database_user_id'] != $data['new']['database_ro_user_id']) {
-					if($db_ro_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+					if($db_ro_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 					else $this->process_host_list('GRANT', $data['new']['database_name'], $db_ro_user['database_user'], $db_ro_user['database_password'], $host_list, $link, '', 'r');
 				}
 			}
@@ -527,23 +566,23 @@ class mysql_clientdb_plugin {
 			//* Remote access option has changed.
 			if($data['new']['remote_access'] != $data['old']['remote_access']) {
 
-				//* set new priveliges
+				//* set new privileges
 				if($data['new']['remote_access'] == 'y') {
 					if($db_user) {
 						if($db_user['database_user'] == 'root'){
-							$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+							$app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 						} else {
 							$this->process_host_list('GRANT', $data['new']['database_name'], $db_user['database_user'], $db_user['database_password'], $data['new']['remote_ips'], $link, '', ($data['new']['quota_exceeded'] == 'y' ? 'rd' : 'rw'));
 						}
 					}
 					if($db_ro_user && $data['new']['database_user_id'] != $data['new']['database_ro_user_id']) {
-						if($db_ro_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+						if($db_ro_user['database_user'] == 'root') $app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 						else $this->process_host_list('GRANT', $data['new']['database_name'], $db_ro_user['database_user'], $db_ro_user['database_password'], $data['new']['remote_ips'], $link, '', 'r');
 					}
 				} else {
 					if($old_db_user) {
 						if($old_db_user['database_user'] == 'root'){
-							$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+							$app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 						} else {
 							// Find out users to drop and users to revoke
 							$drop_or_revoke_user = $this->drop_or_revoke_user($data['old']['database_id'], $data['old']['database_user_id'], $data['old']['remote_ips']);
@@ -553,7 +592,7 @@ class mysql_clientdb_plugin {
 					}
 					if($old_db_ro_user && $data['old']['database_user_id'] != $data['old']['database_ro_user_id']) {
 						if($old_db_ro_user['database_user'] == 'root'){
-							$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+							$app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 						} else {
 							// Find out users to drop and users to revoke
 							$drop_or_revoke_user = $this->drop_or_revoke_user($data['old']['database_id'], $data['old']['database_ro_user_id'], $data['old']['remote_ips']);
@@ -567,7 +606,7 @@ class mysql_clientdb_plugin {
 				//* Change remote access list
 				if($old_db_user) {
 					if($old_db_user['database_user'] == 'root'){
-						$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+						$app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 					} else {
 						// Find out users to drop and users to revoke
 						$drop_or_revoke_user = $this->drop_or_revoke_user($data['old']['database_id'], $data['old']['database_user_id'], $data['old']['remote_ips']);
@@ -577,7 +616,7 @@ class mysql_clientdb_plugin {
 				}
 				if($db_user) {
 					if($db_user['database_user'] == 'root'){
-						$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+						$app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 					} else {
 						$this->process_host_list('GRANT', $data['new']['database_name'], $db_user['database_user'], $db_user['database_password'], $data['new']['remote_ips'], $link, '', ($data['new']['quota_exceeded'] == 'y' ? 'rd' : 'rw'));
 					}
@@ -585,7 +624,7 @@ class mysql_clientdb_plugin {
 
 				if($old_db_ro_user && $data['old']['database_user_id'] != $data['old']['database_ro_user_id']) {
 					if($old_db_ro_user['database_user'] == 'root'){
-						$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+						$app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 					} else {
 						// Find out users to drop and users to revoke
 						$drop_or_revoke_user = $this->drop_or_revoke_user($data['old']['database_id'], $data['old']['database_ro_user_id'], $data['old']['remote_ips']);
@@ -596,7 +635,7 @@ class mysql_clientdb_plugin {
 
 				if($db_ro_user && $data['new']['database_user_id'] != $data['new']['database_ro_user_id']) {
 					if($db_ro_user['database_user'] == 'root'){
-						$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
+						$app->log('User root not allowed for Client databases', LOGLEVEL_WARN);
 					} else {
 						$this->process_host_list('GRANT', $data['new']['database_name'], $db_ro_user['database_user'], $db_ro_user['database_password'], $data['new']['remote_ips'], $link, '', 'r');
 					}
@@ -617,6 +656,7 @@ class mysql_clientdb_plugin {
 				return;
 			}
 
+			mysqli_report(MYSQLI_REPORT_OFF);
 			//* Connect to the database
 			$link = new mysqli($clientdb_host, $clientdb_user, $clientdb_password);
 			if ($link->connect_error) {
@@ -649,7 +689,7 @@ class mysql_clientdb_plugin {
 			if($link->query('DROP DATABASE `'.$link->escape_string($data['old']['database_name'].'`'))) {
 				$app->log('Dropping MySQL database: '.$data['old']['database_name'], LOGLEVEL_DEBUG);
 			} else {
-				$app->log('Error while dropping MySQL database: '.$data['old']['database_name'].' '.$link->error, LOGLEVEL_WARNING);
+				$app->log('Error while dropping MySQL database: '.$data['old']['database_name'].' '.$link->error, LOGLEVEL_WARN);
 			}
 
 			$link->close();
@@ -672,6 +712,7 @@ class mysql_clientdb_plugin {
 			return;
 		}
 
+		mysqli_report(MYSQLI_REPORT_OFF);
 		//* Connect to the database
 		$link = new mysqli($clientdb_host, $clientdb_user, $clientdb_password);
 		if ($link->connect_error) {
@@ -745,6 +786,7 @@ class mysql_clientdb_plugin {
 			return;
 		}
 
+		mysqli_report(MYSQLI_REPORT_OFF);
 		//* Connect to the database
 		$link = new mysqli($clientdb_host, $clientdb_user, $clientdb_password);
 		if ($link->connect_error) {
@@ -771,6 +813,43 @@ class mysql_clientdb_plugin {
 		$link->close();
 	}
 
+
+
+
+	function getDatabaseType($link) {
+		$result = $link->query('SELECT VERSION() as version');
+		if($result) {
+			$tmp = $result->fetch_assoc();
+			$result->free();
+
+			if(stristr($tmp['version'],'mariadb')) {
+				return 'mariadb';
+			} else {
+				return 'mysql';
+			}
+		} else {
+			return false;
+		}
+	}
+
+	function getDatabaseVersion($link, $major_version_only = false) {
+		$result = $link->query('SELECT VERSION() as version');
+		if($result) {
+			$tmp = $result->fetch_assoc();
+			$result->free();
+
+			$version = explode('-', $tmp['version']);
+			if($major_version_only == true) {
+				$version_parts = explode('.', $version[0]);
+				return $version_parts[0];
+			} else {
+				return $version[0];
+			}
+		} else {
+			return false;
+		}
+	}
+
 } // end class
 
-?>
+?>
\ No newline at end of file
