@@ -17,4 +17,4 @@ fi
 CHROOT_HOMEDIR=$1
 CHROOT_APP_PROGRAMS=$2
 
-jk_cp -k $CHROOT_HOMEDIR $CHROOT_APP_PROGRAMS
+jk_cp -j $CHROOT_HOMEDIR $CHROOT_APP_PROGRAMS
