@@ -86,27 +86,20 @@ echo " _____ ___________   _____              __ _
                                              |___/ ";
 echo "\n".str_repeat('-', 80)."\n";
 echo "\n\n>> Update  \n\n";
-echo "Please choose the update method. For production systems select 'stable'. \nWARNING: The update from GIT is only for development systems and may break your current setup. Do not use the GIT version on servers that host any live websites!\nNote: Update all slave server, before you update master server.\n\n";
+echo "Please choose the update method. For production systems select 'stable'. \nWARNING: The update from GIT is only for development systems and may break your current setup. Do not use the GIT version on servers that host any live websites!\nNote: On Multiserver systems, enable maintenance mode and update your master server first. Then update all slave servers, and disable maintenance mode when all servers are updated.\n\n";
 
-$method = simple_query('Select update method', array('stable', 'git-stable', 'git-master'), 'stable');
+$method = simple_query('Select update method', array('stable', 'nightly', 'git-develop'), 'stable');
 
 if($method == 'stable') {
-	$new_version = @file_get_contents('http://www.ispconfig.org/downloads/ispconfig3_version.txt') or die('Unable to retrieve version file.');
+	$new_version = @file_get_contents('https://www.ispconfig.org/downloads/ispconfig3_version.txt') or die('Unable to retrieve version file.');
 	$new_version = trim($new_version);
-	if(version_compare($new_version, ISPC_APP_VERSION, '>')) {
-		passthru('/usr/local/ispconfig/server/scripts/update_stable.sh');
-		exit;
-	} else {
+	if(version_compare($new_version, ISPC_APP_VERSION, '<=') && !in_array('--force', $argv, true)) {
 		echo "There are no updates available for ISPConfig ".ISPC_APP_VERSION."\n";
+		echo "If you are sure you want to update to stable anyway, please use --force parameter\n";
+		echo "DOWNGRADING MAY CAUSE ISSUES!\n";
+		exit(1);
 	}
-} elseif ($method == 'git-stable') {
-	passthru('/usr/local/ispconfig/server/scripts/update_from_dev_stable.sh');
-	exit;
-} else {
-	passthru('/usr/local/ispconfig/server/scripts/update_from_dev.sh');
-	exit;
 }
 
-
-
-?>
+passthru('/usr/local/ispconfig/server/scripts/update_runner.sh ' . escapeshellarg($method));
+exit;
