@@ -15,14 +15,14 @@ if [ -f /usr/local/ispconfig/server/lib/php.ini ]; then
 fi
 
 cd /usr/local/ispconfig/server
-/usr/bin/php -q \
+$(which php) -q \
     -d disable_classes= \
     -d disable_functions= \
     -d open_basedir= \
     /usr/local/ispconfig/server/server.php
 
 cd /usr/local/ispconfig/security
-/usr/bin/php -q \
+$(which php) -q \
     -d disable_classes= \
     -d disable_functions= \
     -d open_basedir= \
